# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class TaggingprofileSchemaWhen(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'does_not_match_with': 'list[TaggingprofileSchemaWhenDoesnotmatchwith]',
        'equal_to': 'list[TaggingprofileSchemaWhenEqualto]',
        'eval': 'list[TopicSchemaWhereEval]',
        'exists': 'list[TaggingprofileSchemaWhenExists]',
        'greater_than': 'list[TaggingprofileSchemaWhenEqualto]',
        'greater_than_or_equal_to': 'list[TaggingprofileSchemaWhenEqualto]',
        'less_than': 'list[TaggingprofileSchemaWhenEqualto]',
        'less_than_or_equal_to': 'list[TaggingprofileSchemaWhenEqualto]',
        'matches_with': 'list[TaggingprofileSchemaWhenDoesnotmatchwith]',
        'matches_with_scheduler': 'TaggingprofileSchemaWhenMatcheswithscheduler',
        'does_not_match_with_scheduler': 'TaggingprofileSchemaWhenMatcheswithscheduler',
        'not_equal_to': 'list[TaggingprofileSchemaWhenEqualto]'
    }

    attribute_map = {
        'does_not_match_with': 'does-not-match-with',
        'equal_to': 'equal-to',
        'eval': 'eval',
        'exists': 'exists',
        'greater_than': 'greater-than',
        'greater_than_or_equal_to': 'greater-than-or-equal-to',
        'less_than': 'less-than',
        'less_than_or_equal_to': 'less-than-or-equal-to',
        'matches_with': 'matches-with',
        'matches_with_scheduler': 'matches-with-scheduler',
        'does_not_match_with_scheduler': 'does-not-match-with-scheduler',
        'not_equal_to': 'not-equal-to'
    }

    def __init__(self, does_not_match_with=None, equal_to=None, eval=None, exists=None, greater_than=None, greater_than_or_equal_to=None, less_than=None, less_than_or_equal_to=None, matches_with=None, matches_with_scheduler=None, does_not_match_with_scheduler=None, not_equal_to=None):  # noqa: E501
        """TaggingprofileSchemaWhen - a model defined in Swagger"""  # noqa: E501

        self._does_not_match_with = None
        self._equal_to = None
        self._eval = None
        self._exists = None
        self._greater_than = None
        self._greater_than_or_equal_to = None
        self._less_than = None
        self._less_than_or_equal_to = None
        self._matches_with = None
        self._matches_with_scheduler = None
        self._does_not_match_with_scheduler = None
        self._not_equal_to = None
        self.discriminator = None

        if does_not_match_with is not None:
            self.does_not_match_with = does_not_match_with
        if equal_to is not None:
            self.equal_to = equal_to
        if eval is not None:
            self.eval = eval
        if exists is not None:
            self.exists = exists
        if greater_than is not None:
            self.greater_than = greater_than
        if greater_than_or_equal_to is not None:
            self.greater_than_or_equal_to = greater_than_or_equal_to
        if less_than is not None:
            self.less_than = less_than
        if less_than_or_equal_to is not None:
            self.less_than_or_equal_to = less_than_or_equal_to
        if matches_with is not None:
            self.matches_with = matches_with
        if matches_with_scheduler is not None:
            self.matches_with_scheduler = matches_with_scheduler
        if does_not_match_with_scheduler is not None:
            self.does_not_match_with_scheduler = does_not_match_with_scheduler
        if not_equal_to is not None:
            self.not_equal_to = not_equal_to

    @property
    def does_not_match_with(self):
        """Gets the does_not_match_with of this TaggingprofileSchemaWhen.  # noqa: E501


        :return: The does_not_match_with of this TaggingprofileSchemaWhen.  # noqa: E501
        :rtype: list[TaggingprofileSchemaWhenDoesnotmatchwith]
        """
        return self._does_not_match_with

    @does_not_match_with.setter
    def does_not_match_with(self, does_not_match_with):
        """Sets the does_not_match_with of this TaggingprofileSchemaWhen.


        :param does_not_match_with: The does_not_match_with of this TaggingprofileSchemaWhen.  # noqa: E501
        :type: list[TaggingprofileSchemaWhenDoesnotmatchwith]
        """

        self._does_not_match_with = does_not_match_with

    @property
    def equal_to(self):
        """Gets the equal_to of this TaggingprofileSchemaWhen.  # noqa: E501


        :return: The equal_to of this TaggingprofileSchemaWhen.  # noqa: E501
        :rtype: list[TaggingprofileSchemaWhenEqualto]
        """
        return self._equal_to

    @equal_to.setter
    def equal_to(self, equal_to):
        """Sets the equal_to of this TaggingprofileSchemaWhen.


        :param equal_to: The equal_to of this TaggingprofileSchemaWhen.  # noqa: E501
        :type: list[TaggingprofileSchemaWhenEqualto]
        """

        self._equal_to = equal_to

    @property
    def eval(self):
        """Gets the eval of this TaggingprofileSchemaWhen.  # noqa: E501


        :return: The eval of this TaggingprofileSchemaWhen.  # noqa: E501
        :rtype: list[TopicSchemaWhereEval]
        """
        return self._eval

    @eval.setter
    def eval(self, eval):
        """Sets the eval of this TaggingprofileSchemaWhen.


        :param eval: The eval of this TaggingprofileSchemaWhen.  # noqa: E501
        :type: list[TopicSchemaWhereEval]
        """

        self._eval = eval

    @property
    def exists(self):
        """Gets the exists of this TaggingprofileSchemaWhen.  # noqa: E501


        :return: The exists of this TaggingprofileSchemaWhen.  # noqa: E501
        :rtype: list[TaggingprofileSchemaWhenExists]
        """
        return self._exists

    @exists.setter
    def exists(self, exists):
        """Sets the exists of this TaggingprofileSchemaWhen.


        :param exists: The exists of this TaggingprofileSchemaWhen.  # noqa: E501
        :type: list[TaggingprofileSchemaWhenExists]
        """

        self._exists = exists

    @property
    def greater_than(self):
        """Gets the greater_than of this TaggingprofileSchemaWhen.  # noqa: E501


        :return: The greater_than of this TaggingprofileSchemaWhen.  # noqa: E501
        :rtype: list[TaggingprofileSchemaWhenEqualto]
        """
        return self._greater_than

    @greater_than.setter
    def greater_than(self, greater_than):
        """Sets the greater_than of this TaggingprofileSchemaWhen.


        :param greater_than: The greater_than of this TaggingprofileSchemaWhen.  # noqa: E501
        :type: list[TaggingprofileSchemaWhenEqualto]
        """

        self._greater_than = greater_than

    @property
    def greater_than_or_equal_to(self):
        """Gets the greater_than_or_equal_to of this TaggingprofileSchemaWhen.  # noqa: E501


        :return: The greater_than_or_equal_to of this TaggingprofileSchemaWhen.  # noqa: E501
        :rtype: list[TaggingprofileSchemaWhenEqualto]
        """
        return self._greater_than_or_equal_to

    @greater_than_or_equal_to.setter
    def greater_than_or_equal_to(self, greater_than_or_equal_to):
        """Sets the greater_than_or_equal_to of this TaggingprofileSchemaWhen.


        :param greater_than_or_equal_to: The greater_than_or_equal_to of this TaggingprofileSchemaWhen.  # noqa: E501
        :type: list[TaggingprofileSchemaWhenEqualto]
        """

        self._greater_than_or_equal_to = greater_than_or_equal_to

    @property
    def less_than(self):
        """Gets the less_than of this TaggingprofileSchemaWhen.  # noqa: E501


        :return: The less_than of this TaggingprofileSchemaWhen.  # noqa: E501
        :rtype: list[TaggingprofileSchemaWhenEqualto]
        """
        return self._less_than

    @less_than.setter
    def less_than(self, less_than):
        """Sets the less_than of this TaggingprofileSchemaWhen.


        :param less_than: The less_than of this TaggingprofileSchemaWhen.  # noqa: E501
        :type: list[TaggingprofileSchemaWhenEqualto]
        """

        self._less_than = less_than

    @property
    def less_than_or_equal_to(self):
        """Gets the less_than_or_equal_to of this TaggingprofileSchemaWhen.  # noqa: E501


        :return: The less_than_or_equal_to of this TaggingprofileSchemaWhen.  # noqa: E501
        :rtype: list[TaggingprofileSchemaWhenEqualto]
        """
        return self._less_than_or_equal_to

    @less_than_or_equal_to.setter
    def less_than_or_equal_to(self, less_than_or_equal_to):
        """Sets the less_than_or_equal_to of this TaggingprofileSchemaWhen.


        :param less_than_or_equal_to: The less_than_or_equal_to of this TaggingprofileSchemaWhen.  # noqa: E501
        :type: list[TaggingprofileSchemaWhenEqualto]
        """

        self._less_than_or_equal_to = less_than_or_equal_to

    @property
    def matches_with(self):
        """Gets the matches_with of this TaggingprofileSchemaWhen.  # noqa: E501


        :return: The matches_with of this TaggingprofileSchemaWhen.  # noqa: E501
        :rtype: list[TaggingprofileSchemaWhenDoesnotmatchwith]
        """
        return self._matches_with

    @matches_with.setter
    def matches_with(self, matches_with):
        """Sets the matches_with of this TaggingprofileSchemaWhen.


        :param matches_with: The matches_with of this TaggingprofileSchemaWhen.  # noqa: E501
        :type: list[TaggingprofileSchemaWhenDoesnotmatchwith]
        """

        self._matches_with = matches_with

    @property
    def matches_with_scheduler(self):
        """Gets the matches_with_scheduler of this TaggingprofileSchemaWhen.  # noqa: E501


        :return: The matches_with_scheduler of this TaggingprofileSchemaWhen.  # noqa: E501
        :rtype: TaggingprofileSchemaWhenMatcheswithscheduler
        """
        return self._matches_with_scheduler

    @matches_with_scheduler.setter
    def matches_with_scheduler(self, matches_with_scheduler):
        """Sets the matches_with_scheduler of this TaggingprofileSchemaWhen.


        :param matches_with_scheduler: The matches_with_scheduler of this TaggingprofileSchemaWhen.  # noqa: E501
        :type: TaggingprofileSchemaWhenMatcheswithscheduler
        """

        self._matches_with_scheduler = matches_with_scheduler

    @property
    def does_not_match_with_scheduler(self):
        """Gets the does_not_match_with_scheduler of this TaggingprofileSchemaWhen.  # noqa: E501


        :return: The does_not_match_with_scheduler of this TaggingprofileSchemaWhen.  # noqa: E501
        :rtype: TaggingprofileSchemaWhenMatcheswithscheduler
        """
        return self._does_not_match_with_scheduler

    @does_not_match_with_scheduler.setter
    def does_not_match_with_scheduler(self, does_not_match_with_scheduler):
        """Sets the does_not_match_with_scheduler of this TaggingprofileSchemaWhen.


        :param does_not_match_with_scheduler: The does_not_match_with_scheduler of this TaggingprofileSchemaWhen.  # noqa: E501
        :type: TaggingprofileSchemaWhenMatcheswithscheduler
        """

        self._does_not_match_with_scheduler = does_not_match_with_scheduler

    @property
    def not_equal_to(self):
        """Gets the not_equal_to of this TaggingprofileSchemaWhen.  # noqa: E501


        :return: The not_equal_to of this TaggingprofileSchemaWhen.  # noqa: E501
        :rtype: list[TaggingprofileSchemaWhenEqualto]
        """
        return self._not_equal_to

    @not_equal_to.setter
    def not_equal_to(self, not_equal_to):
        """Sets the not_equal_to of this TaggingprofileSchemaWhen.


        :param not_equal_to: The not_equal_to of this TaggingprofileSchemaWhen.  # noqa: E501
        :type: list[TaggingprofileSchemaWhenEqualto]
        """

        self._not_equal_to = not_equal_to

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TaggingprofileSchemaWhen, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TaggingprofileSchemaWhen):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from jnpr.healthbot.swagger.api_client import ApiClient


class SystemApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def generate_resource_dependencies(self, **kwargs):  # noqa: E501
        """Resource dependencies  # noqa: E501

        Get resource dependency events. Internal API  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.generate_resource_dependencies(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_iam_token: authentication header object
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.generate_resource_dependencies_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.generate_resource_dependencies_with_http_info(**kwargs)  # noqa: E501
            return data

    def generate_resource_dependencies_with_http_info(self, **kwargs):  # noqa: E501
        """Resource dependencies  # noqa: E501

        Get resource dependency events. Internal API  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.generate_resource_dependencies_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_iam_token: authentication header object
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['x_iam_token']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method generate_resource_dependencies" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'x_iam_token' in params:
            header_params['x-iam-token'] = params['x_iam_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/config/rca/generate-resource-dependencies', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def query_tsdb(self, db, device_group, device, **kwargs):  # noqa: E501
        """TSDB query  # noqa: E501

        Query TSDB  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.query_tsdb(db, device_group, device, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str db: Name of the database. Multiple databases should be separated by ','. '*' can be used to specify all databases. (required)
        :param str device_group: Name of the deviceGroup(s). Multiple device groups should be separated by ','. This can be used in combination with device, but is not mandatory. If device is given, then query will be executed only for that particular devices in the given device group, else all devices in group will be considered. Given devices will be applicable for all give device-groups. (required)
        :param str device: Name of the device. Multiple device should be separated by ','. This should be used along with deviceGroup. Without deviceGroup, this config will not be considered (required)
        :param str measurement: Name of the measurement. Optional if topic/rule/trigger is used
        :param str topic: Name of Healthbot topic. Optional if measurement is used
        :param str rule: Name of Healthbot rule. Required if topic is used. Optional if measurement is used
        :param str trigger: Name of Healthbot trigger. Optional if measurement is used or rule table is being queried
        :param str fields: Fields that needs to be retrieved. Use * for to query all fields. Eg: fields=field1, field2
        :param str order: Sort points in descending order based on time. By default points will be sorted in ascending order. Eg: order=desc
        :param str group_by: Group results based on specified tags. Use * to group by all tags. Eg: groupBy=key1, key2
        :param str limit: Limit number of points in the result. If groupBy is used limit is applied per group. Eg: limit=10
        :param str where: Where clause filters data based on fields, tags, and/or timestamps. Eg: where=\"interface-name\" = 'ge-0/0/1' and \"in-pkts\" > 0
        :param str q: Influx query string. Use this when custom query format does not support a query
        :return: TsdbResults
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.query_tsdb_with_http_info(db, device_group, device, **kwargs)  # noqa: E501
        else:
            (data) = self.query_tsdb_with_http_info(db, device_group, device, **kwargs)  # noqa: E501
            return data

    def query_tsdb_with_http_info(self, db, device_group, device, **kwargs):  # noqa: E501
        """TSDB query  # noqa: E501

        Query TSDB  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.query_tsdb_with_http_info(db, device_group, device, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str db: Name of the database. Multiple databases should be separated by ','. '*' can be used to specify all databases. (required)
        :param str device_group: Name of the deviceGroup(s). Multiple device groups should be separated by ','. This can be used in combination with device, but is not mandatory. If device is given, then query will be executed only for that particular devices in the given device group, else all devices in group will be considered. Given devices will be applicable for all give device-groups. (required)
        :param str device: Name of the device. Multiple device should be separated by ','. This should be used along with deviceGroup. Without deviceGroup, this config will not be considered (required)
        :param str measurement: Name of the measurement. Optional if topic/rule/trigger is used
        :param str topic: Name of Healthbot topic. Optional if measurement is used
        :param str rule: Name of Healthbot rule. Required if topic is used. Optional if measurement is used
        :param str trigger: Name of Healthbot trigger. Optional if measurement is used or rule table is being queried
        :param str fields: Fields that needs to be retrieved. Use * for to query all fields. Eg: fields=field1, field2
        :param str order: Sort points in descending order based on time. By default points will be sorted in ascending order. Eg: order=desc
        :param str group_by: Group results based on specified tags. Use * to group by all tags. Eg: groupBy=key1, key2
        :param str limit: Limit number of points in the result. If groupBy is used limit is applied per group. Eg: limit=10
        :param str where: Where clause filters data based on fields, tags, and/or timestamps. Eg: where=\"interface-name\" = 'ge-0/0/1' and \"in-pkts\" > 0
        :param str q: Influx query string. Use this when custom query format does not support a query
        :return: TsdbResults
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['db', 'device_group', 'device', 'measurement', 'topic', 'rule', 'trigger', 'fields', 'order', 'group_by', 'limit', 'where', 'q']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method query_tsdb" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'db' is set
        if ('db' not in params or
                params['db'] is None):
            raise ValueError("Missing the required parameter `db` when calling `query_tsdb`")  # noqa: E501
        # verify the required parameter 'device_group' is set
        if ('device_group' not in params or
                params['device_group'] is None):
            raise ValueError("Missing the required parameter `device_group` when calling `query_tsdb`")  # noqa: E501
        # verify the required parameter 'device' is set
        if ('device' not in params or
                params['device'] is None):
            raise ValueError("Missing the required parameter `device` when calling `query_tsdb`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'db' in params:
            query_params.append(('db', params['db']))  # noqa: E501
        if 'device_group' in params:
            query_params.append(('deviceGroup', params['device_group']))  # noqa: E501
        if 'device' in params:
            query_params.append(('device', params['device']))  # noqa: E501
        if 'measurement' in params:
            query_params.append(('measurement', params['measurement']))  # noqa: E501
        if 'topic' in params:
            query_params.append(('topic', params['topic']))  # noqa: E501
        if 'rule' in params:
            query_params.append(('rule', params['rule']))  # noqa: E501
        if 'trigger' in params:
            query_params.append(('trigger', params['trigger']))  # noqa: E501
        if 'fields' in params:
            query_params.append(('fields', params['fields']))  # noqa: E501
        if 'order' in params:
            query_params.append(('order', params['order']))  # noqa: E501
        if 'group_by' in params:
            query_params.append(('groupBy', params['group_by']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'where' in params:
            query_params.append(('where', params['where']))  # noqa: E501
        if 'q' in params:
            query_params.append(('q', params['q']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/tsdb/query', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TsdbResults',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def query_tsdb_post(self, db, device_group, device, **kwargs):  # noqa: E501
        """TSDB query  # noqa: E501

        Query TSDB  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.query_tsdb_post(db, device_group, device, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str db: Name of the database. Multiple databases should be separated by ','. '*' can be used to specify all databases. (required)
        :param str device_group: Name of the deviceGroup(s). Multiple device groups should be separated by ','. This can be used in combination with device, but is not mandatory. If device is given, then query will be executed only for that particular devices in the given device group, else all devices in group will be considered. Given devices will be applicable for all give device-groups. (required)
        :param str device: Name of the device. Multiple device should be separated by ','. This should be used along with deviceGroup. Without deviceGroup, this config will not be considered (required)
        :param TsdbPostBody tsdb_query_body: Query TSDB body object
        :param str measurement: Name of the measurement. Optional if topic/rule/trigger is used
        :param str topic: Name of Healthbot topic. Optional if measurement is used
        :param str rule: Name of Healthbot rule. Required if topic is used. Optional if measurement is used
        :param str trigger: Name of Healthbot trigger. Optional if measurement is used or rule table is being queried
        :param str fields: Fields that needs to be retrieved. Use * for to query all fields. Eg: fields=field1, field2
        :param str order: Sort points in descending order based on time. By default points will be sorted in ascending order. Eg: order=desc
        :param str group_by: Group results based on specified tags. Use * to group by all tags. Eg: groupBy=key1, key2
        :param str limit: Limit number of points in the result. If groupBy is used limit is applied per group. Eg: limit=10
        :param str where: Where clause filters data based on fields, tags, and/or timestamps. Eg: where=\"interface-name\" = 'ge-0/0/1' and \"in-pkts\" > 0
        :param str q: Influx query string. Use this when custom query format does not support a query
        :return: TsdbResults
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.query_tsdb_post_with_http_info(db, device_group, device, **kwargs)  # noqa: E501
        else:
            (data) = self.query_tsdb_post_with_http_info(db, device_group, device, **kwargs)  # noqa: E501
            return data

    def query_tsdb_post_with_http_info(self, db, device_group, device, **kwargs):  # noqa: E501
        """TSDB query  # noqa: E501

        Query TSDB  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.query_tsdb_post_with_http_info(db, device_group, device, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str db: Name of the database. Multiple databases should be separated by ','. '*' can be used to specify all databases. (required)
        :param str device_group: Name of the deviceGroup(s). Multiple device groups should be separated by ','. This can be used in combination with device, but is not mandatory. If device is given, then query will be executed only for that particular devices in the given device group, else all devices in group will be considered. Given devices will be applicable for all give device-groups. (required)
        :param str device: Name of the device. Multiple device should be separated by ','. This should be used along with deviceGroup. Without deviceGroup, this config will not be considered (required)
        :param TsdbPostBody tsdb_query_body: Query TSDB body object
        :param str measurement: Name of the measurement. Optional if topic/rule/trigger is used
        :param str topic: Name of Healthbot topic. Optional if measurement is used
        :param str rule: Name of Healthbot rule. Required if topic is used. Optional if measurement is used
        :param str trigger: Name of Healthbot trigger. Optional if measurement is used or rule table is being queried
        :param str fields: Fields that needs to be retrieved. Use * for to query all fields. Eg: fields=field1, field2
        :param str order: Sort points in descending order based on time. By default points will be sorted in ascending order. Eg: order=desc
        :param str group_by: Group results based on specified tags. Use * to group by all tags. Eg: groupBy=key1, key2
        :param str limit: Limit number of points in the result. If groupBy is used limit is applied per group. Eg: limit=10
        :param str where: Where clause filters data based on fields, tags, and/or timestamps. Eg: where=\"interface-name\" = 'ge-0/0/1' and \"in-pkts\" > 0
        :param str q: Influx query string. Use this when custom query format does not support a query
        :return: TsdbResults
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['db', 'device_group', 'device', 'tsdb_query_body', 'measurement', 'topic', 'rule', 'trigger', 'fields', 'order', 'group_by', 'limit', 'where', 'q']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method query_tsdb_post" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'db' is set
        if ('db' not in params or
                params['db'] is None):
            raise ValueError("Missing the required parameter `db` when calling `query_tsdb_post`")  # noqa: E501
        # verify the required parameter 'device_group' is set
        if ('device_group' not in params or
                params['device_group'] is None):
            raise ValueError("Missing the required parameter `device_group` when calling `query_tsdb_post`")  # noqa: E501
        # verify the required parameter 'device' is set
        if ('device' not in params or
                params['device'] is None):
            raise ValueError("Missing the required parameter `device` when calling `query_tsdb_post`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'db' in params:
            query_params.append(('db', params['db']))  # noqa: E501
        if 'device_group' in params:
            query_params.append(('deviceGroup', params['device_group']))  # noqa: E501
        if 'device' in params:
            query_params.append(('device', params['device']))  # noqa: E501
        if 'measurement' in params:
            query_params.append(('measurement', params['measurement']))  # noqa: E501
        if 'topic' in params:
            query_params.append(('topic', params['topic']))  # noqa: E501
        if 'rule' in params:
            query_params.append(('rule', params['rule']))  # noqa: E501
        if 'trigger' in params:
            query_params.append(('trigger', params['trigger']))  # noqa: E501
        if 'fields' in params:
            query_params.append(('fields', params['fields']))  # noqa: E501
        if 'order' in params:
            query_params.append(('order', params['order']))  # noqa: E501
        if 'group_by' in params:
            query_params.append(('groupBy', params['group_by']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'where' in params:
            query_params.append(('where', params['where']))  # noqa: E501
        if 'q' in params:
            query_params.append(('q', params['q']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'tsdb_query_body' in params:
            body_params = params['tsdb_query_body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/octet-stream'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/tsdb/query', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TsdbResults',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def retrieve_available_nodes(self, **kwargs):  # noqa: E501
        """List of available nodes  # noqa: E501

        Get the list of available nodes in the installation.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_available_nodes(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_iam_token: authentication header object
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.retrieve_available_nodes_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.retrieve_available_nodes_with_http_info(**kwargs)  # noqa: E501
            return data

    def retrieve_available_nodes_with_http_info(self, **kwargs):  # noqa: E501
        """List of available nodes  # noqa: E501

        Get the list of available nodes in the installation.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_available_nodes_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_iam_token: authentication header object
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['x_iam_token']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method retrieve_available_nodes" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'x_iam_token' in params:
            header_params['x-iam-token'] = params['x_iam_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/nodes/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def retrieve_sensor_device_group(self, device_group_name, **kwargs):  # noqa: E501
        """Get all All API's.  # noqa: E501

        GET sensors subscribed for a device-group  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_sensor_device_group(device_group_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str device_group_name: Device Group (required)
        :param str x_iam_token: authentication header object
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.retrieve_sensor_device_group_with_http_info(device_group_name, **kwargs)  # noqa: E501
        else:
            (data) = self.retrieve_sensor_device_group_with_http_info(device_group_name, **kwargs)  # noqa: E501
            return data

    def retrieve_sensor_device_group_with_http_info(self, device_group_name, **kwargs):  # noqa: E501
        """Get all All API's.  # noqa: E501

        GET sensors subscribed for a device-group  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_sensor_device_group_with_http_info(device_group_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str device_group_name: Device Group (required)
        :param str x_iam_token: authentication header object
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['device_group_name', 'x_iam_token']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method retrieve_sensor_device_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'device_group_name' is set
        if ('device_group_name' not in params or
                params['device_group_name'] is None):
            raise ValueError("Missing the required parameter `device_group_name` when calling `retrieve_sensor_device_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'device_group_name' in params:
            path_params['device_group_name'] = params['device_group_name']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_iam_token' in params:
            header_params['x-iam-token'] = params['x_iam_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/config/sensor/device-group/{device_group_name}/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def retrieve_system_details(self, **kwargs):  # noqa: E501
        """Retrieve system details.  # noqa: E501

        Retrieve system details for HealthBot system.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_system_details(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_iam_token: authentication header object
        :param str service_name: service name takes in the name of the service for which details are required.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.retrieve_system_details_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.retrieve_system_details_with_http_info(**kwargs)  # noqa: E501
            return data

    def retrieve_system_details_with_http_info(self, **kwargs):  # noqa: E501
        """Retrieve system details.  # noqa: E501

        Retrieve system details for HealthBot system.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_system_details_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_iam_token: authentication header object
        :param str service_name: service name takes in the name of the service for which details are required.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['x_iam_token', 'service_name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method retrieve_system_details" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'service_name' in params:
            query_params.append(('service_name', params['service_name']))  # noqa: E501

        header_params = {}
        if 'x_iam_token' in params:
            header_params['x-iam-token'] = params['x_iam_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/system-details/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def retrieve_tsdb_counters(self, **kwargs):  # noqa: E501
        """TSDB counters  # noqa: E501

        Get TSDB counters  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_tsdb_counters(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_iam_token: authentication header object
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.retrieve_tsdb_counters_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.retrieve_tsdb_counters_with_http_info(**kwargs)  # noqa: E501
            return data

    def retrieve_tsdb_counters_with_http_info(self, **kwargs):  # noqa: E501
        """TSDB counters  # noqa: E501

        Get TSDB counters  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_tsdb_counters_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_iam_token: authentication header object
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['x_iam_token']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method retrieve_tsdb_counters" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'x_iam_token' in params:
            header_params['x-iam-token'] = params['x_iam_token']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/tsdb-counters/', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class CounterRecordSchema(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'enterprise': 'int',
        'field': 'list[SflowSchemaSflowField]',
        'format': 'int',
        'record_name': 'str'
    }

    attribute_map = {
        'enterprise': 'enterprise',
        'field': 'field',
        'format': 'format',
        'record_name': 'record-name'
    }

    def __init__(self, enterprise=None, field=None, format=None, record_name=None):  # noqa: E501
        """CounterRecordSchema - a model defined in Swagger"""  # noqa: E501

        self._enterprise = None
        self._field = None
        self._format = None
        self._record_name = None
        self.discriminator = None

        self.enterprise = enterprise
        self.field = field
        self.format = format
        self.record_name = record_name

    @property
    def enterprise(self):
        """Gets the enterprise of this CounterRecordSchema.  # noqa: E501

        Enterprise to which record belongs  # noqa: E501

        :return: The enterprise of this CounterRecordSchema.  # noqa: E501
        :rtype: int
        """
        return self._enterprise

    @enterprise.setter
    def enterprise(self, enterprise):
        """Sets the enterprise of this CounterRecordSchema.

        Enterprise to which record belongs  # noqa: E501

        :param enterprise: The enterprise of this CounterRecordSchema.  # noqa: E501
        :type: int
        """
        if enterprise is None:
            raise ValueError("Invalid value for `enterprise`, must not be `None`")  # noqa: E501

        self._enterprise = enterprise

    @property
    def field(self):
        """Gets the field of this CounterRecordSchema.  # noqa: E501

        List of fields  # noqa: E501

        :return: The field of this CounterRecordSchema.  # noqa: E501
        :rtype: list[SflowSchemaSflowField]
        """
        return self._field

    @field.setter
    def field(self, field):
        """Sets the field of this CounterRecordSchema.

        List of fields  # noqa: E501

        :param field: The field of this CounterRecordSchema.  # noqa: E501
        :type: list[SflowSchemaSflowField]
        """
        if field is None:
            raise ValueError("Invalid value for `field`, must not be `None`")  # noqa: E501

        self._field = field

    @property
    def format(self):
        """Gets the format of this CounterRecordSchema.  # noqa: E501

        Format of record  # noqa: E501

        :return: The format of this CounterRecordSchema.  # noqa: E501
        :rtype: int
        """
        return self._format

    @format.setter
    def format(self, format):
        """Sets the format of this CounterRecordSchema.

        Format of record  # noqa: E501

        :param format: The format of this CounterRecordSchema.  # noqa: E501
        :type: int
        """
        if format is None:
            raise ValueError("Invalid value for `format`, must not be `None`")  # noqa: E501

        self._format = format

    @property
    def record_name(self):
        """Gets the record_name of this CounterRecordSchema.  # noqa: E501

        Name of record  # noqa: E501

        :return: The record_name of this CounterRecordSchema.  # noqa: E501
        :rtype: str
        """
        return self._record_name

    @record_name.setter
    def record_name(self, record_name):
        """Sets the record_name of this CounterRecordSchema.

        Name of record  # noqa: E501

        :param record_name: The record_name of this CounterRecordSchema.  # noqa: E501
        :type: str
        """
        if record_name is None:
            raise ValueError("Invalid value for `record_name`, must not be `None`")  # noqa: E501

        self._record_name = record_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CounterRecordSchema, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CounterRecordSchema):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa
"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from jnpr.healthbot.swagger.models.affected_groups import AffectedGroups
from jnpr.healthbot.swagger.models.apply_macro_schema import ApplyMacroSchema
from jnpr.healthbot.swagger.models.applymacro_schema_data import ApplymacroSchemaData
from jnpr.healthbot.swagger.models.associated_group_schema import AssociatedGroupSchema
from jnpr.healthbot.swagger.models.associated_role_schema import AssociatedRoleSchema
from jnpr.healthbot.swagger.models.associated_role_schema_inner import AssociatedRoleSchemaInner
from jnpr.healthbot.swagger.models.associated_user_schema import AssociatedUserSchema
from jnpr.healthbot.swagger.models.associated_user_schema_inner import AssociatedUserSchemaInner
from jnpr.healthbot.swagger.models.ca_profile_schema import CaProfileSchema
from jnpr.healthbot.swagger.models.command_rpc import CommandRpc
from jnpr.healthbot.swagger.models.commit_job import CommitJob
from jnpr.healthbot.swagger.models.counter_record_schema import CounterRecordSchema
from jnpr.healthbot.swagger.models.credenetial import Credenetial
from jnpr.healthbot.swagger.models.credential import Credential
from jnpr.healthbot.swagger.models.custom_plugin_schema import CustomPluginSchema
from jnpr.healthbot.swagger.models.custom_plugins_schema import CustomPluginsSchema
from jnpr.healthbot.swagger.models.customplugin_schema_parameters import CustompluginSchemaParameters
from jnpr.healthbot.swagger.models.customplugin_schema_securityparameters import CustompluginSchemaSecurityparameters
from jnpr.healthbot.swagger.models.customplugin_schema_securityparameters_tls import CustompluginSchemaSecurityparametersTls
from jnpr.healthbot.swagger.models.customplugin_schema_securityparameters_userauthentication import CustompluginSchemaSecurityparametersUserauthentication
from jnpr.healthbot.swagger.models.datastore_schema import DatastoreSchema
from jnpr.healthbot.swagger.models.debug_arguments_schema import DebugArgumentsSchema
from jnpr.healthbot.swagger.models.debug_job_response_schema import DebugJobResponseSchema
from jnpr.healthbot.swagger.models.deployment_schema import DeploymentSchema
from jnpr.healthbot.swagger.models.deployment_schema_deployment import DeploymentSchemaDeployment
from jnpr.healthbot.swagger.models.deployment_schema_deployment_kubernetes import DeploymentSchemaDeploymentKubernetes
from jnpr.healthbot.swagger.models.deployment_schema_deployment_kubernetes_loadbalancer import DeploymentSchemaDeploymentKubernetesLoadbalancer
from jnpr.healthbot.swagger.models.deployment_schema_deployment_kubernetes_loadbalancer_snmpproxy import DeploymentSchemaDeploymentKubernetesLoadbalancerSnmpproxy
from jnpr.healthbot.swagger.models.destination_schema import DestinationSchema
from jnpr.healthbot.swagger.models.destination_schema_disk import DestinationSchemaDisk
from jnpr.healthbot.swagger.models.destination_schema_email import DestinationSchemaEmail
from jnpr.healthbot.swagger.models.destinations_schema import DestinationsSchema
from jnpr.healthbot.swagger.models.device_details_schema import DeviceDetailsSchema
from jnpr.healthbot.swagger.models.device_field_capture_schema import DeviceFieldCaptureSchema
from jnpr.healthbot.swagger.models.device_group_field_capture_schema import DeviceGroupFieldCaptureSchema
from jnpr.healthbot.swagger.models.device_group_health_tree import DeviceGroupHealthTree
from jnpr.healthbot.swagger.models.device_group_schema import DeviceGroupSchema
from jnpr.healthbot.swagger.models.device_groups_schema import DeviceGroupsSchema
from jnpr.healthbot.swagger.models.device_health_schema import DeviceHealthSchema
from jnpr.healthbot.swagger.models.device_health_tree import DeviceHealthTree
from jnpr.healthbot.swagger.models.device_schema import DeviceSchema
from jnpr.healthbot.swagger.models.device_schema_flow import DeviceSchemaFlow
from jnpr.healthbot.swagger.models.device_schema_i_agent import DeviceSchemaIAgent
from jnpr.healthbot.swagger.models.device_schema_openconfig import DeviceSchemaOpenconfig
from jnpr.healthbot.swagger.models.device_schema_outboundssh import DeviceSchemaOutboundssh
from jnpr.healthbot.swagger.models.device_schema_snmp import DeviceSchemaSnmp
from jnpr.healthbot.swagger.models.device_schema_snmp_v2 import DeviceSchemaSnmpV2
from jnpr.healthbot.swagger.models.device_schema_snmp_v2_sourceid import DeviceSchemaSnmpV2Sourceid
from jnpr.healthbot.swagger.models.device_schema_snmp_v3 import DeviceSchemaSnmpV3
from jnpr.healthbot.swagger.models.device_schema_snmp_v3_sourceid import DeviceSchemaSnmpV3Sourceid
from jnpr.healthbot.swagger.models.device_schema_snmp_v3_usm import DeviceSchemaSnmpV3Usm
from jnpr.healthbot.swagger.models.device_schema_syslog import DeviceSchemaSyslog
from jnpr.healthbot.swagger.models.device_schema_variable import DeviceSchemaVariable
from jnpr.healthbot.swagger.models.device_schema_vendor import DeviceSchemaVendor
from jnpr.healthbot.swagger.models.device_schema_vendor_arista import DeviceSchemaVendorArista
from jnpr.healthbot.swagger.models.device_schema_vendor_cisco import DeviceSchemaVendorCisco
from jnpr.healthbot.swagger.models.device_schema_vendor_juniper import DeviceSchemaVendorJuniper
from jnpr.healthbot.swagger.models.device_schema_vendor_linux import DeviceSchemaVendorLinux
from jnpr.healthbot.swagger.models.device_schema_vendor_othervendor import DeviceSchemaVendorOthervendor
from jnpr.healthbot.swagger.models.device_schema_vendor_paloalto import DeviceSchemaVendorPaloalto
from jnpr.healthbot.swagger.models.devicegroup_schema_actionscheduler import DevicegroupSchemaActionscheduler
from jnpr.healthbot.swagger.models.devicegroup_schema_authentication import DevicegroupSchemaAuthentication
from jnpr.healthbot.swagger.models.devicegroup_schema_authentication_password import DevicegroupSchemaAuthenticationPassword
from jnpr.healthbot.swagger.models.devicegroup_schema_authentication_ssh import DevicegroupSchemaAuthenticationSsh
from jnpr.healthbot.swagger.models.devicegroup_schema_authentication_ssl import DevicegroupSchemaAuthenticationSsl
from jnpr.healthbot.swagger.models.devicegroup_schema_fielddata import DevicegroupSchemaFielddata
from jnpr.healthbot.swagger.models.devicegroup_schema_fielddata_rollup import DevicegroupSchemaFielddataRollup
from jnpr.healthbot.swagger.models.devicegroup_schema_flow import DevicegroupSchemaFlow
from jnpr.healthbot.swagger.models.devicegroup_schema_flow_netflow import DevicegroupSchemaFlowNetflow
from jnpr.healthbot.swagger.models.devicegroup_schema_flow_sflow import DevicegroupSchemaFlowSflow
from jnpr.healthbot.swagger.models.devicegroup_schema_logging import DevicegroupSchemaLogging
from jnpr.healthbot.swagger.models.devicegroup_schema_logging_byoi import DevicegroupSchemaLoggingByoi
from jnpr.healthbot.swagger.models.devicegroup_schema_logging_byoi_service import DevicegroupSchemaLoggingByoiService
from jnpr.healthbot.swagger.models.devicegroup_schema_logging_flow import DevicegroupSchemaLoggingFlow
from jnpr.healthbot.swagger.models.devicegroup_schema_logging_i_agent import DevicegroupSchemaLoggingIAgent
from jnpr.healthbot.swagger.models.devicegroup_schema_logging_m_lmodelbuilder import DevicegroupSchemaLoggingMLmodelbuilder
from jnpr.healthbot.swagger.models.devicegroup_schema_logging_nativegpb import DevicegroupSchemaLoggingNativegpb
from jnpr.healthbot.swagger.models.devicegroup_schema_logging_nonsensorrules import DevicegroupSchemaLoggingNonsensorrules
from jnpr.healthbot.swagger.models.devicegroup_schema_logging_openconfig import DevicegroupSchemaLoggingOpenconfig
from jnpr.healthbot.swagger.models.devicegroup_schema_logging_reportsgeneration import DevicegroupSchemaLoggingReportsgeneration
from jnpr.healthbot.swagger.models.devicegroup_schema_logging_resourcediscovery import DevicegroupSchemaLoggingResourcediscovery
from jnpr.healthbot.swagger.models.devicegroup_schema_logging_servermonitoring import DevicegroupSchemaLoggingServermonitoring
from jnpr.healthbot.swagger.models.devicegroup_schema_logging_sflow import DevicegroupSchemaLoggingSflow
from jnpr.healthbot.swagger.models.devicegroup_schema_logging_snmp import DevicegroupSchemaLoggingSnmp
from jnpr.healthbot.swagger.models.devicegroup_schema_logging_snmpnotification import DevicegroupSchemaLoggingSnmpnotification
from jnpr.healthbot.swagger.models.devicegroup_schema_logging_syslog import DevicegroupSchemaLoggingSyslog
from jnpr.healthbot.swagger.models.devicegroup_schema_logging_triggerevaluation import DevicegroupSchemaLoggingTriggerevaluation
from jnpr.healthbot.swagger.models.devicegroup_schema_nativegpb import DevicegroupSchemaNativegpb
from jnpr.healthbot.swagger.models.devicegroup_schema_notification import DevicegroupSchemaNotification
from jnpr.healthbot.swagger.models.devicegroup_schema_openconfig import DevicegroupSchemaOpenconfig
from jnpr.healthbot.swagger.models.devicegroup_schema_openconfig_gnmi import DevicegroupSchemaOpenconfigGnmi
from jnpr.healthbot.swagger.models.devicegroup_schema_outboundssh import DevicegroupSchemaOutboundssh
from jnpr.healthbot.swagger.models.devicegroup_schema_publish import DevicegroupSchemaPublish
from jnpr.healthbot.swagger.models.devicegroup_schema_rawdata import DevicegroupSchemaRawdata
from jnpr.healthbot.swagger.models.devicegroup_schema_rawdata_summarize import DevicegroupSchemaRawdataSummarize
from jnpr.healthbot.swagger.models.devicegroup_schema_rootcauseanalysis import DevicegroupSchemaRootcauseanalysis
from jnpr.healthbot.swagger.models.devicegroup_schema_scheduler import DevicegroupSchemaScheduler
from jnpr.healthbot.swagger.models.devicegroup_schema_snmp import DevicegroupSchemaSnmp
from jnpr.healthbot.swagger.models.devicegroup_schema_snmp_v2 import DevicegroupSchemaSnmpV2
from jnpr.healthbot.swagger.models.devicegroup_schema_snmp_v3 import DevicegroupSchemaSnmpV3
from jnpr.healthbot.swagger.models.devicegroup_schema_snmp_v3_usm import DevicegroupSchemaSnmpV3Usm
from jnpr.healthbot.swagger.models.devicegroup_schema_snmp_v3_usm_snmpproxyforwarder import DevicegroupSchemaSnmpV3UsmSnmpproxyforwarder
from jnpr.healthbot.swagger.models.devicegroup_schema_syslog import DevicegroupSchemaSyslog
from jnpr.healthbot.swagger.models.devicegroup_schema_variable import DevicegroupSchemaVariable
from jnpr.healthbot.swagger.models.devicegroup_schema_variablevalue import DevicegroupSchemaVariablevalue
from jnpr.healthbot.swagger.models.devices_schema import DevicesSchema
from jnpr.healthbot.swagger.models.dynamic_tagging_schema_object import DynamicTaggingSchemaObject
from jnpr.healthbot.swagger.models.dynamic_taggings_schema_object import DynamicTaggingsSchemaObject
from jnpr.healthbot.swagger.models.edge_schema import EdgeSchema
from jnpr.healthbot.swagger.models.error import Error
from jnpr.healthbot.swagger.models.event import Event
from jnpr.healthbot.swagger.models.field_capture_schema import FieldCaptureSchema
from jnpr.healthbot.swagger.models.field_field_capture_schema import FieldFieldCaptureSchema
from jnpr.healthbot.swagger.models.flow_record_schema import FlowRecordSchema
from jnpr.healthbot.swagger.models.flow_schema import FlowSchema
from jnpr.healthbot.swagger.models.flow_schema_flow import FlowSchemaFlow
from jnpr.healthbot.swagger.models.flow_schema_flow_recognitionpattern import FlowSchemaFlowRecognitionpattern
from jnpr.healthbot.swagger.models.flow_schema_flow_template import FlowSchemaFlowTemplate
from jnpr.healthbot.swagger.models.frequency_profile_schema import FrequencyProfileSchema
from jnpr.healthbot.swagger.models.frequencyprofile_schema_nonsensor import FrequencyprofileSchemaNonsensor
from jnpr.healthbot.swagger.models.frequencyprofile_schema_sensor import FrequencyprofileSchemaSensor
from jnpr.healthbot.swagger.models.group_health_schema import GroupHealthSchema
from jnpr.healthbot.swagger.models.hb_graphs import HbGraphs
from jnpr.healthbot.swagger.models.hb_graphs_query import HbGraphsQuery
from jnpr.healthbot.swagger.models.hb_graphs_query_where import HbGraphsQueryWhere
from jnpr.healthbot.swagger.models.hb_graphs_query_where_where_clause import HbGraphsQueryWhereWhereClause
from jnpr.healthbot.swagger.models.header_pattern_schema import HeaderPatternSchema
from jnpr.healthbot.swagger.models.headerpattern_schema_field import HeaderpatternSchemaField
from jnpr.healthbot.swagger.models.health_schema import HealthSchema
from jnpr.healthbot.swagger.models.ingest_mapping_schema import IngestMappingSchema
from jnpr.healthbot.swagger.models.ingest_mappings_schema import IngestMappingsSchema
from jnpr.healthbot.swagger.models.ingest_settings_schema import IngestSettingsSchema
from jnpr.healthbot.swagger.models.ingestmapping_schema_i_agent import IngestmappingSchemaIAgent
from jnpr.healthbot.swagger.models.ingestmapping_schema_i_agent_useplugin import IngestmappingSchemaIAgentUseplugin
from jnpr.healthbot.swagger.models.ingestmapping_schema_nativegpb import IngestmappingSchemaNativegpb
from jnpr.healthbot.swagger.models.ingestmapping_schema_netflow import IngestmappingSchemaNetflow
from jnpr.healthbot.swagger.models.ingestmapping_schema_openconfig import IngestmappingSchemaOpenconfig
from jnpr.healthbot.swagger.models.ingestmapping_schema_snmp import IngestmappingSchemaSnmp
from jnpr.healthbot.swagger.models.ingestmapping_schema_syslog import IngestmappingSchemaSyslog
from jnpr.healthbot.swagger.models.inline_response200 import InlineResponse200
from jnpr.healthbot.swagger.models.inline_response2001 import InlineResponse2001
from jnpr.healthbot.swagger.models.inline_response2002 import InlineResponse2002
from jnpr.healthbot.swagger.models.instance_schedule_state_schema import InstanceScheduleStateSchema
from jnpr.healthbot.swagger.models.instances_schedule_state_schema import InstancesScheduleStateSchema
from jnpr.healthbot.swagger.models.lhs_rhs_group import LhsRhsGroup
from jnpr.healthbot.swagger.models.license_feature_schema import LicenseFeatureSchema
from jnpr.healthbot.swagger.models.license_features_schema import LicenseFeaturesSchema
from jnpr.healthbot.swagger.models.license_key_schema import LicenseKeySchema
from jnpr.healthbot.swagger.models.license_keys_schema import LicenseKeysSchema
from jnpr.healthbot.swagger.models.license_raw_key_schema import LicenseRawKeySchema
from jnpr.healthbot.swagger.models.license_raw_keys_schema import LicenseRawKeysSchema
from jnpr.healthbot.swagger.models.licensekey_schema_features import LicensekeySchemaFeatures
from jnpr.healthbot.swagger.models.local_certificate_schema import LocalCertificateSchema
from jnpr.healthbot.swagger.models.native_gpb_schema import NativeGpbSchema
from jnpr.healthbot.swagger.models.nativegpb_schema_nativegpb import NativegpbSchemaNativegpb
from jnpr.healthbot.swagger.models.network_group_schema import NetworkGroupSchema
from jnpr.healthbot.swagger.models.network_groups_schema import NetworkGroupsSchema
from jnpr.healthbot.swagger.models.network_health_tree import NetworkHealthTree
from jnpr.healthbot.swagger.models.networkgroup_schema_logging import NetworkgroupSchemaLogging
from jnpr.healthbot.swagger.models.networkgroup_schema_notification import NetworkgroupSchemaNotification
from jnpr.healthbot.swagger.models.networkgroup_schema_publish import NetworkgroupSchemaPublish
from jnpr.healthbot.swagger.models.notification_schema import NotificationSchema
from jnpr.healthbot.swagger.models.notification_schema_amqppublish import NotificationSchemaAmqppublish
from jnpr.healthbot.swagger.models.notification_schema_amqppublish_sasl import NotificationSchemaAmqppublishSasl
from jnpr.healthbot.swagger.models.notification_schema_emails import NotificationSchemaEmails
from jnpr.healthbot.swagger.models.notification_schema_emails_filter import NotificationSchemaEmailsFilter
from jnpr.healthbot.swagger.models.notification_schema_httppost import NotificationSchemaHttppost
from jnpr.healthbot.swagger.models.notification_schema_httppost_basic import NotificationSchemaHttppostBasic
from jnpr.healthbot.swagger.models.notification_schema_kafkapublish import NotificationSchemaKafkapublish
from jnpr.healthbot.swagger.models.notification_schema_kafkapublish_sasl import NotificationSchemaKafkapublishSasl
from jnpr.healthbot.swagger.models.notification_schema_microsoftteams import NotificationSchemaMicrosoftteams
from jnpr.healthbot.swagger.models.notification_schema_slack import NotificationSchemaSlack
from jnpr.healthbot.swagger.models.notifications_schema import NotificationsSchema
from jnpr.healthbot.swagger.models.organization_schema import OrganizationSchema
from jnpr.healthbot.swagger.models.organizations_schema import OrganizationsSchema
from jnpr.healthbot.swagger.models.outbound_ssh_schema import OutboundSshSchema
from jnpr.healthbot.swagger.models.outboundssh_schema_outboundssh import OutboundsshSchemaOutboundssh
from jnpr.healthbot.swagger.models.panel_data_schema import PanelDataSchema
from jnpr.healthbot.swagger.models.panel_data_schema_add_group_by_tag import PanelDataSchemaAddGroupByTag
from jnpr.healthbot.swagger.models.panel_data_schema_add_where_condition import PanelDataSchemaAddWhereCondition
from jnpr.healthbot.swagger.models.panel_data_schema_add_where_condition_key_or_field import PanelDataSchemaAddWhereConditionKeyOrField
from jnpr.healthbot.swagger.models.panel_data_schema_add_where_condition_key_or_field_value import PanelDataSchemaAddWhereConditionKeyOrFieldValue
from jnpr.healthbot.swagger.models.panel_data_schema_add_where_condition_operator import PanelDataSchemaAddWhereConditionOperator
from jnpr.healthbot.swagger.models.panel_data_schema_change_where_key_field import PanelDataSchemaChangeWhereKeyField
from jnpr.healthbot.swagger.models.panel_data_schema_group_by_fill import PanelDataSchemaGroupByFill
from jnpr.healthbot.swagger.models.panel_data_schema_group_by_time import PanelDataSchemaGroupByTime
from jnpr.healthbot.swagger.models.panel_data_schema_selected_aggregation import PanelDataSchemaSelectedAggregation
from jnpr.healthbot.swagger.models.panel_data_schema_selected_device import PanelDataSchemaSelectedDevice
from jnpr.healthbot.swagger.models.panel_data_schema_selected_dropdown import PanelDataSchemaSelectedDropdown
from jnpr.healthbot.swagger.models.panel_data_schema_selected_field import PanelDataSchemaSelectedField
from jnpr.healthbot.swagger.models.panel_data_schema_selected_group import PanelDataSchemaSelectedGroup
from jnpr.healthbot.swagger.models.panel_data_schema_selected_logical_operator import PanelDataSchemaSelectedLogicalOperator
from jnpr.healthbot.swagger.models.panel_data_schema_selected_topic import PanelDataSchemaSelectedTopic
from jnpr.healthbot.swagger.models.panel_data_schema_selected_transformation import PanelDataSchemaSelectedTransformation
from jnpr.healthbot.swagger.models.panel_schema import PanelSchema
from jnpr.healthbot.swagger.models.panel_schema_panel_query import PanelSchemaPanelQuery
from jnpr.healthbot.swagger.models.panel_schema_panel_type import PanelSchemaPanelType
from jnpr.healthbot.swagger.models.panel_schema_time_range import PanelSchemaTimeRange
from jnpr.healthbot.swagger.models.panel_schema_unit_type import PanelSchemaUnitType
from jnpr.healthbot.swagger.models.pattern_schema import PatternSchema
from jnpr.healthbot.swagger.models.pattern_schema_constant import PatternSchemaConstant
from jnpr.healthbot.swagger.models.pattern_schema_field import PatternSchemaField
from jnpr.healthbot.swagger.models.pattern_set_schema import PatternSetSchema
from jnpr.healthbot.swagger.models.playbook_schema import PlaybookSchema
from jnpr.healthbot.swagger.models.playbooks_schema import PlaybooksSchema
from jnpr.healthbot.swagger.models.profile_schema import ProfileSchema
from jnpr.healthbot.swagger.models.profile_schema_datasummarization import ProfileSchemaDatasummarization
from jnpr.healthbot.swagger.models.profile_schema_datasummarization_path import ProfileSchemaDatasummarizationPath
from jnpr.healthbot.swagger.models.profile_schema_datasummarization_raw import ProfileSchemaDatasummarizationRaw
from jnpr.healthbot.swagger.models.profile_schema_rollupsummarization import ProfileSchemaRollupsummarization
from jnpr.healthbot.swagger.models.profile_schema_security import ProfileSchemaSecurity
from jnpr.healthbot.swagger.models.profiles_schema import ProfilesSchema
from jnpr.healthbot.swagger.models.profiles_schema_profile import ProfilesSchemaProfile
from jnpr.healthbot.swagger.models.protocol_schema import ProtocolSchema
from jnpr.healthbot.swagger.models.raw_data_summarizations_schema import RawDataSummarizationsSchema
from jnpr.healthbot.swagger.models.raw_schema import RawSchema
from jnpr.healthbot.swagger.models.raw_schema_datatype import RawSchemaDatatype
from jnpr.healthbot.swagger.models.raw_schema_path import RawSchemaPath
from jnpr.healthbot.swagger.models.refresh_token import RefreshToken
from jnpr.healthbot.swagger.models.report_generation_schema import ReportGenerationSchema
from jnpr.healthbot.swagger.models.report_schema import ReportSchema
from jnpr.healthbot.swagger.models.report_schema_canvaspanel import ReportSchemaCanvaspanel
from jnpr.healthbot.swagger.models.report_schema_graphcanvas import ReportSchemaGraphcanvas
from jnpr.healthbot.swagger.models.reports_schema import ReportsSchema
from jnpr.healthbot.swagger.models.resource_schema import ResourceSchema
from jnpr.healthbot.swagger.models.retention_policies_schema import RetentionPoliciesSchema
from jnpr.healthbot.swagger.models.retention_policy_schema import RetentionPolicySchema
from jnpr.healthbot.swagger.models.role_schema import RoleSchema
from jnpr.healthbot.swagger.models.role_schema_inner import RoleSchemaInner
from jnpr.healthbot.swagger.models.rollup_summarization_schema import RollupSummarizationSchema
from jnpr.healthbot.swagger.models.rollup_summarizations_schema import RollupSummarizationsSchema
from jnpr.healthbot.swagger.models.rollupsummarization_schema_database import RollupsummarizationSchemaDatabase
from jnpr.healthbot.swagger.models.rollupsummarization_schema_datarolluporder import RollupsummarizationSchemaDatarolluporder
from jnpr.healthbot.swagger.models.rollupsummarization_schema_field import RollupsummarizationSchemaField
from jnpr.healthbot.swagger.models.rollupsummarization_schema_field1 import RollupsummarizationSchemaField1
from jnpr.healthbot.swagger.models.rollupsummarization_schema_measurement import RollupsummarizationSchemaMeasurement
from jnpr.healthbot.swagger.models.rollupsummarization_schema_rule import RollupsummarizationSchemaRule
from jnpr.healthbot.swagger.models.rule_field_capture_schema import RuleFieldCaptureSchema
from jnpr.healthbot.swagger.models.rule_schema import RuleSchema
from jnpr.healthbot.swagger.models.rule_schema_argument import RuleSchemaArgument
from jnpr.healthbot.swagger.models.rule_schema_byoi import RuleSchemaByoi
from jnpr.healthbot.swagger.models.rule_schema_byoi_plugin import RuleSchemaByoiPlugin
from jnpr.healthbot.swagger.models.rule_schema_byoi_plugin_parameters import RuleSchemaByoiPluginParameters
from jnpr.healthbot.swagger.models.rule_schema_constant import RuleSchemaConstant
from jnpr.healthbot.swagger.models.rule_schema_dataifmissing import RuleSchemaDataifmissing
from jnpr.healthbot.swagger.models.rule_schema_field import RuleSchemaField
from jnpr.healthbot.swagger.models.rule_schema_flow import RuleSchemaFlow
from jnpr.healthbot.swagger.models.rule_schema_formula import RuleSchemaFormula
from jnpr.healthbot.swagger.models.rule_schema_formula1 import RuleSchemaFormula1
from jnpr.healthbot.swagger.models.rule_schema_formula1_and import RuleSchemaFormula1And
from jnpr.healthbot.swagger.models.rule_schema_formula1_or import RuleSchemaFormula1Or
from jnpr.healthbot.swagger.models.rule_schema_formula1_unique import RuleSchemaFormula1Unique
from jnpr.healthbot.swagger.models.rule_schema_formula1_unless import RuleSchemaFormula1Unless
from jnpr.healthbot.swagger.models.rule_schema_formula_anomalydetection import RuleSchemaFormulaAnomalydetection
from jnpr.healthbot.swagger.models.rule_schema_formula_concatenate import RuleSchemaFormulaConcatenate
from jnpr.healthbot.swagger.models.rule_schema_formula_count import RuleSchemaFormulaCount
from jnpr.healthbot.swagger.models.rule_schema_formula_dynamicthreshold import RuleSchemaFormulaDynamicthreshold
from jnpr.healthbot.swagger.models.rule_schema_formula_elapsedtime import RuleSchemaFormulaElapsedtime
from jnpr.healthbot.swagger.models.rule_schema_formula_eval import RuleSchemaFormulaEval
from jnpr.healthbot.swagger.models.rule_schema_formula_max import RuleSchemaFormulaMax
from jnpr.healthbot.swagger.models.rule_schema_formula_mean import RuleSchemaFormulaMean
from jnpr.healthbot.swagger.models.rule_schema_formula_microburst import RuleSchemaFormulaMicroburst
from jnpr.healthbot.swagger.models.rule_schema_formula_min import RuleSchemaFormulaMin
from jnpr.healthbot.swagger.models.rule_schema_formula_outlierdetection import RuleSchemaFormulaOutlierdetection
from jnpr.healthbot.swagger.models.rule_schema_formula_outlierdetection_algorithm import RuleSchemaFormulaOutlierdetectionAlgorithm
from jnpr.healthbot.swagger.models.rule_schema_formula_outlierdetection_algorithm_dbscan import RuleSchemaFormulaOutlierdetectionAlgorithmDbscan
from jnpr.healthbot.swagger.models.rule_schema_formula_outlierdetection_algorithm_dbscan_sensitivity import RuleSchemaFormulaOutlierdetectionAlgorithmDbscanSensitivity
from jnpr.healthbot.swagger.models.rule_schema_formula_outlierdetection_algorithm_kfold3sigma import RuleSchemaFormulaOutlierdetectionAlgorithmKfold3sigma
from jnpr.healthbot.swagger.models.rule_schema_formula_predict import RuleSchemaFormulaPredict
from jnpr.healthbot.swagger.models.rule_schema_formula_rateofchange import RuleSchemaFormulaRateofchange
from jnpr.healthbot.swagger.models.rule_schema_formula_stddev import RuleSchemaFormulaStddev
from jnpr.healthbot.swagger.models.rule_schema_formula_sum import RuleSchemaFormulaSum
from jnpr.healthbot.swagger.models.rule_schema_formula_userdefinedfunction import RuleSchemaFormulaUserdefinedfunction
from jnpr.healthbot.swagger.models.rule_schema_formula_userdefinedfunction_argument import RuleSchemaFormulaUserdefinedfunctionArgument
from jnpr.healthbot.swagger.models.rule_schema_formula_valuedifference import RuleSchemaFormulaValuedifference
from jnpr.healthbot.swagger.models.rule_schema_function import RuleSchemaFunction
from jnpr.healthbot.swagger.models.rule_schema_i_agent import RuleSchemaIAgent
from jnpr.healthbot.swagger.models.rule_schema_i_agent_args import RuleSchemaIAgentArgs
from jnpr.healthbot.swagger.models.rule_schema_nativegpb import RuleSchemaNativegpb
from jnpr.healthbot.swagger.models.rule_schema_openconfig import RuleSchemaOpenconfig
from jnpr.healthbot.swagger.models.rule_schema_reference import RuleSchemaReference
from jnpr.healthbot.swagger.models.rule_schema_reference_dataifmissing import RuleSchemaReferenceDataifmissing
from jnpr.healthbot.swagger.models.rule_schema_ruleproperties import RuleSchemaRuleproperties
from jnpr.healthbot.swagger.models.rule_schema_ruleproperties_catalogue import RuleSchemaRulepropertiesCatalogue
from jnpr.healthbot.swagger.models.rule_schema_ruleproperties_helperfiles import RuleSchemaRulepropertiesHelperfiles
from jnpr.healthbot.swagger.models.rule_schema_ruleproperties_supporteddevices import RuleSchemaRulepropertiesSupporteddevices
from jnpr.healthbot.swagger.models.rule_schema_ruleproperties_supporteddevices_juniper import RuleSchemaRulepropertiesSupporteddevicesJuniper
from jnpr.healthbot.swagger.models.rule_schema_ruleproperties_supporteddevices_juniper_operatingsystem import RuleSchemaRulepropertiesSupporteddevicesJuniperOperatingsystem
from jnpr.healthbot.swagger.models.rule_schema_ruleproperties_supporteddevices_juniper_platforms import RuleSchemaRulepropertiesSupporteddevicesJuniperPlatforms
from jnpr.healthbot.swagger.models.rule_schema_ruleproperties_supporteddevices_juniper_products import RuleSchemaRulepropertiesSupporteddevicesJuniperProducts
from jnpr.healthbot.swagger.models.rule_schema_ruleproperties_supporteddevices_juniper_releases import RuleSchemaRulepropertiesSupporteddevicesJuniperReleases
from jnpr.healthbot.swagger.models.rule_schema_ruleproperties_supporteddevices_juniper_releases1 import RuleSchemaRulepropertiesSupporteddevicesJuniperReleases1
from jnpr.healthbot.swagger.models.rule_schema_ruleproperties_supporteddevices_operatingsystems import RuleSchemaRulepropertiesSupporteddevicesOperatingsystems
from jnpr.healthbot.swagger.models.rule_schema_ruleproperties_supporteddevices_othervendor import RuleSchemaRulepropertiesSupporteddevicesOthervendor
from jnpr.healthbot.swagger.models.rule_schema_ruleproperties_supporteddevices_platforms import RuleSchemaRulepropertiesSupporteddevicesPlatforms
from jnpr.healthbot.swagger.models.rule_schema_ruleproperties_supporteddevices_products import RuleSchemaRulepropertiesSupporteddevicesProducts
from jnpr.healthbot.swagger.models.rule_schema_ruleproperties_supporteddevices_releases import RuleSchemaRulepropertiesSupporteddevicesReleases
from jnpr.healthbot.swagger.models.rule_schema_sensor import RuleSchemaSensor
from jnpr.healthbot.swagger.models.rule_schema_sensor1 import RuleSchemaSensor1
from jnpr.healthbot.swagger.models.rule_schema_sflow import RuleSchemaSflow
from jnpr.healthbot.swagger.models.rule_schema_snmp import RuleSchemaSnmp
from jnpr.healthbot.swagger.models.rule_schema_snmpnotification import RuleSchemaSnmpnotification
from jnpr.healthbot.swagger.models.rule_schema_syslog import RuleSchemaSyslog
from jnpr.healthbot.swagger.models.rule_schema_term import RuleSchemaTerm
from jnpr.healthbot.swagger.models.rule_schema_then import RuleSchemaThen
from jnpr.healthbot.swagger.models.rule_schema_then_argument import RuleSchemaThenArgument
from jnpr.healthbot.swagger.models.rule_schema_then_retry import RuleSchemaThenRetry
from jnpr.healthbot.swagger.models.rule_schema_then_retry_backoff import RuleSchemaThenRetryBackoff
from jnpr.healthbot.swagger.models.rule_schema_then_status import RuleSchemaThenStatus
from jnpr.healthbot.swagger.models.rule_schema_then_userdefinedaction import RuleSchemaThenUserdefinedaction
from jnpr.healthbot.swagger.models.rule_schema_then_workflow import RuleSchemaThenWorkflow
from jnpr.healthbot.swagger.models.rule_schema_trigger import RuleSchemaTrigger
from jnpr.healthbot.swagger.models.rule_schema_variable import RuleSchemaVariable
from jnpr.healthbot.swagger.models.rule_schema_vector import RuleSchemaVector
from jnpr.healthbot.swagger.models.rule_schema_when import RuleSchemaWhen
from jnpr.healthbot.swagger.models.rule_schema_when_doesnotmatchwith import RuleSchemaWhenDoesnotmatchwith
from jnpr.healthbot.swagger.models.rule_schema_when_equalto import RuleSchemaWhenEqualto
from jnpr.healthbot.swagger.models.rule_schema_when_exists import RuleSchemaWhenExists
from jnpr.healthbot.swagger.models.rule_schema_when_increasingatleastbyrate import RuleSchemaWhenIncreasingatleastbyrate
from jnpr.healthbot.swagger.models.rule_schema_when_increasingatleastbyvalue import RuleSchemaWhenIncreasingatleastbyvalue
from jnpr.healthbot.swagger.models.rule_schema_when_maxrateofincrease import RuleSchemaWhenMaxrateofincrease
from jnpr.healthbot.swagger.models.rule_schema_when_range import RuleSchemaWhenRange
from jnpr.healthbot.swagger.models.rule_schema_when_userdefinedfunction import RuleSchemaWhenUserdefinedfunction
from jnpr.healthbot.swagger.models.rule_schema_where import RuleSchemaWhere
from jnpr.healthbot.swagger.models.sample_schema import SampleSchema
from jnpr.healthbot.swagger.models.scheduler_schema import SchedulerSchema
from jnpr.healthbot.swagger.models.scheduler_schema_repeat import SchedulerSchemaRepeat
from jnpr.healthbot.swagger.models.scheduler_schema_repeat_interval import SchedulerSchemaRepeatInterval
from jnpr.healthbot.swagger.models.scheduler_schema_runfor import SchedulerSchemaRunfor
from jnpr.healthbot.swagger.models.schedulers_schema import SchedulersSchema
from jnpr.healthbot.swagger.models.service_status import ServiceStatus
from jnpr.healthbot.swagger.models.sflow_schema import SflowSchema
from jnpr.healthbot.swagger.models.sflow_schema_sflow import SflowSchemaSflow
from jnpr.healthbot.swagger.models.sflow_schema_sflow_counterrecord import SflowSchemaSflowCounterrecord
from jnpr.healthbot.swagger.models.sflow_schema_sflow_field import SflowSchemaSflowField
from jnpr.healthbot.swagger.models.sflow_schema_sflow_protocol import SflowSchemaSflowProtocol
from jnpr.healthbot.swagger.models.sflow_schema_sflow_sample import SflowSchemaSflowSample
from jnpr.healthbot.swagger.models.sflow_schema_sflow_sizebasedonfield import SflowSchemaSflowSizebasedonfield
from jnpr.healthbot.swagger.models.sflow_schema_sflow_sizebasedonfield_then import SflowSchemaSflowSizebasedonfieldThen
from jnpr.healthbot.swagger.models.sflow_schema_sflow_sizebasedonfield_then1 import SflowSchemaSflowSizebasedonfieldThen1
from jnpr.healthbot.swagger.models.sflow_schema_sflow_sizebasedonfield_whenequal import SflowSchemaSflowSizebasedonfieldWhenequal
from jnpr.healthbot.swagger.models.site_schema import SiteSchema
from jnpr.healthbot.swagger.models.snmp_notification_schema import SnmpNotificationSchema
from jnpr.healthbot.swagger.models.snmpnotification_schema_snmpnotification import SnmpnotificationSchemaSnmpnotification
from jnpr.healthbot.swagger.models.snmpnotification_schema_snmpnotification_v3 import SnmpnotificationSchemaSnmpnotificationV3
from jnpr.healthbot.swagger.models.snmpnotification_schema_snmpnotification_v3_usm import SnmpnotificationSchemaSnmpnotificationV3Usm
from jnpr.healthbot.swagger.models.snmpv3_usm_user_schema import Snmpv3UsmUserSchema
from jnpr.healthbot.swagger.models.snmpv3_usm_users_schema import Snmpv3UsmUsersSchema
from jnpr.healthbot.swagger.models.snmpv3usmuser_schema_authentication import Snmpv3usmuserSchemaAuthentication
from jnpr.healthbot.swagger.models.snmpv3usmuser_schema_privacy import Snmpv3usmuserSchemaPrivacy
from jnpr.healthbot.swagger.models.ssh_key_profile_schema import SshKeyProfileSchema
from jnpr.healthbot.swagger.models.syslog_schema import SyslogSchema
from jnpr.healthbot.swagger.models.syslog_schema_syslog import SyslogSchemaSyslog
from jnpr.healthbot.swagger.models.system_settings_schema import SystemSettingsSchema
from jnpr.healthbot.swagger.models.table_schema import TableSchema
from jnpr.healthbot.swagger.models.tagging_profile_schema import TaggingProfileSchema
from jnpr.healthbot.swagger.models.tagging_profiles_schema import TaggingProfilesSchema
from jnpr.healthbot.swagger.models.taggingprofile_schema_policy import TaggingprofileSchemaPolicy
from jnpr.healthbot.swagger.models.taggingprofile_schema_term import TaggingprofileSchemaTerm
from jnpr.healthbot.swagger.models.taggingprofile_schema_then import TaggingprofileSchemaThen
from jnpr.healthbot.swagger.models.taggingprofile_schema_then_addfield import TaggingprofileSchemaThenAddfield
from jnpr.healthbot.swagger.models.taggingprofile_schema_then_addkey import TaggingprofileSchemaThenAddkey
from jnpr.healthbot.swagger.models.taggingprofile_schema_when import TaggingprofileSchemaWhen
from jnpr.healthbot.swagger.models.taggingprofile_schema_when_doesnotmatchwith import TaggingprofileSchemaWhenDoesnotmatchwith
from jnpr.healthbot.swagger.models.taggingprofile_schema_when_equalto import TaggingprofileSchemaWhenEqualto
from jnpr.healthbot.swagger.models.taggingprofile_schema_when_exists import TaggingprofileSchemaWhenExists
from jnpr.healthbot.swagger.models.taggingprofile_schema_when_matcheswithscheduler import TaggingprofileSchemaWhenMatcheswithscheduler
from jnpr.healthbot.swagger.models.template_schema import TemplateSchema
from jnpr.healthbot.swagger.models.time_range_mandatory import TimeRangeMandatory
from jnpr.healthbot.swagger.models.tlive_kafka_oc_schema import TliveKafkaOcSchema
from jnpr.healthbot.swagger.models.tlive_kafka_ocs_schema import TliveKafkaOcsSchema
from jnpr.healthbot.swagger.models.tlivekafkaoc_schema_security import TlivekafkaocSchemaSecurity
from jnpr.healthbot.swagger.models.tlivekafkaoc_schema_security_sasl import TlivekafkaocSchemaSecuritySasl
from jnpr.healthbot.swagger.models.token import Token
from jnpr.healthbot.swagger.models.topic_field_capture_schema import TopicFieldCaptureSchema
from jnpr.healthbot.swagger.models.topic_schema import TopicSchema
from jnpr.healthbot.swagger.models.topic_schema_argument import TopicSchemaArgument
from jnpr.healthbot.swagger.models.topic_schema_dependson import TopicSchemaDependson
from jnpr.healthbot.swagger.models.topic_schema_field import TopicSchemaField
from jnpr.healthbot.swagger.models.topic_schema_foreverydevice import TopicSchemaForeverydevice
from jnpr.healthbot.swagger.models.topic_schema_foreverynetworkgroup import TopicSchemaForeverynetworkgroup
from jnpr.healthbot.swagger.models.topic_schema_function import TopicSchemaFunction
from jnpr.healthbot.swagger.models.topic_schema_getdependenciesfromcache import TopicSchemaGetdependenciesfromcache
from jnpr.healthbot.swagger.models.topic_schema_locateresource import TopicSchemaLocateresource
from jnpr.healthbot.swagger.models.topic_schema_resource import TopicSchemaResource
from jnpr.healthbot.swagger.models.topic_schema_source import TopicSchemaSource
from jnpr.healthbot.swagger.models.topic_schema_source_rule import TopicSchemaSourceRule
from jnpr.healthbot.swagger.models.topic_schema_term import TopicSchemaTerm
from jnpr.healthbot.swagger.models.topic_schema_userdefinedfunction import TopicSchemaUserdefinedfunction
from jnpr.healthbot.swagger.models.topic_schema_variable import TopicSchemaVariable
from jnpr.healthbot.swagger.models.topic_schema_where import TopicSchemaWhere
from jnpr.healthbot.swagger.models.topic_schema_where_argument import TopicSchemaWhereArgument
from jnpr.healthbot.swagger.models.topic_schema_where_doesnotmatchwith import TopicSchemaWhereDoesnotmatchwith
from jnpr.healthbot.swagger.models.topic_schema_where_equalto import TopicSchemaWhereEqualto
from jnpr.healthbot.swagger.models.topic_schema_where_eval import TopicSchemaWhereEval
from jnpr.healthbot.swagger.models.topic_schema_where_matcheswith import TopicSchemaWhereMatcheswith
from jnpr.healthbot.swagger.models.topic_schema_where_userdefinedfunction import TopicSchemaWhereUserdefinedfunction
from jnpr.healthbot.swagger.models.topic_schema_withcapturegroup import TopicSchemaWithcapturegroup
from jnpr.healthbot.swagger.models.topics_schema import TopicsSchema
from jnpr.healthbot.swagger.models.trigger_action_schema import TriggerActionSchema
from jnpr.healthbot.swagger.models.trigger_schema import TriggerSchema
from jnpr.healthbot.swagger.models.trigger_schema_triggers import TriggerSchemaTriggers
from jnpr.healthbot.swagger.models.tsdb_error import TsdbError
from jnpr.healthbot.swagger.models.tsdb_error_results import TsdbErrorResults
from jnpr.healthbot.swagger.models.tsdb_post_body import TsdbPostBody
from jnpr.healthbot.swagger.models.tsdb_post_body_items import TsdbPostBodyItems
from jnpr.healthbot.swagger.models.tsdb_post_body_items_device_aggregation import TsdbPostBodyItemsDeviceAggregation
from jnpr.healthbot.swagger.models.tsdb_post_body_items_outer_queries import TsdbPostBodyItemsOuterQueries
from jnpr.healthbot.swagger.models.tsdb_results import TsdbResults
from jnpr.healthbot.swagger.models.tsdb_results_results import TsdbResultsResults
from jnpr.healthbot.swagger.models.tsdb_results_series import TsdbResultsSeries
from jnpr.healthbot.swagger.models.tsdb_schema import TsdbSchema
from jnpr.healthbot.swagger.models.user_schema import UserSchema
from jnpr.healthbot.swagger.models.user_schema_groups import UserSchemaGroups
from jnpr.healthbot.swagger.models.uuid_object import UuidObject
from jnpr.healthbot.swagger.models.when_lhs_rhs_group import WhenLhsRhsGroup
from jnpr.healthbot.swagger.models.workflow_argument_group_schema import WorkflowArgumentGroupSchema
from jnpr.healthbot.swagger.models.workflow_argument_group_schema_inner import WorkflowArgumentGroupSchemaInner
from jnpr.healthbot.swagger.models.workflow_command_schema import WorkflowCommandSchema
from jnpr.healthbot.swagger.models.workflow_command_schema_commands import WorkflowCommandSchemaCommands
from jnpr.healthbot.swagger.models.workflow_cron_options_schema import WorkflowCronOptionsSchema
from jnpr.healthbot.swagger.models.workflow_instance_schema import WorkflowInstanceSchema
from jnpr.healthbot.swagger.models.workflow_instance_schema_parameters import WorkflowInstanceSchemaParameters
from jnpr.healthbot.swagger.models.workflow_instances_schema import WorkflowInstancesSchema
from jnpr.healthbot.swagger.models.workflow_notification_schema import WorkflowNotificationSchema
from jnpr.healthbot.swagger.models.workflow_schema import WorkflowSchema
from jnpr.healthbot.swagger.models.workflow_schema_artifact import WorkflowSchemaArtifact
from jnpr.healthbot.swagger.models.workflow_schema_dataxml import WorkflowSchemaDataxml
from jnpr.healthbot.swagger.models.workflow_schema_grok import WorkflowSchemaGrok
from jnpr.healthbot.swagger.models.workflow_schema_input import WorkflowSchemaInput
from jnpr.healthbot.swagger.models.workflow_schema_json import WorkflowSchemaJson
from jnpr.healthbot.swagger.models.workflow_schema_output import WorkflowSchemaOutput
from jnpr.healthbot.swagger.models.workflow_schema_regex import WorkflowSchemaRegex
from jnpr.healthbot.swagger.models.workflow_schema_step import WorkflowSchemaStep
from jnpr.healthbot.swagger.models.workflow_schema_suspend import WorkflowSchemaSuspend
from jnpr.healthbot.swagger.models.workflow_schema_task import WorkflowSchemaTask
from jnpr.healthbot.swagger.models.workflow_schema_task1 import WorkflowSchemaTask1
from jnpr.healthbot.swagger.models.workflow_schema_workflow import WorkflowSchemaWorkflow
from jnpr.healthbot.swagger.models.workflow_statistics_schema import WorkflowStatisticsSchema
from jnpr.healthbot.swagger.models.workflows_schema import WorkflowsSchema



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class DevicegroupSchemaOpenconfigGnmi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'enable': 'bool',
        'encoding': 'str'
    }

    attribute_map = {
        'enable': 'enable',
        'encoding': 'encoding'
    }

    def __init__(self, enable=None, encoding=None):  # noqa: E501
        """DevicegroupSchemaOpenconfigGnmi - a model defined in Swagger"""  # noqa: E501

        self._enable = None
        self._encoding = None
        self.discriminator = None

        if enable is not None:
            self.enable = enable
        if encoding is not None:
            self.encoding = encoding

    @property
    def enable(self):
        """Gets the enable of this DevicegroupSchemaOpenconfigGnmi.  # noqa: E501

        If true, enable gnmi  # noqa: E501

        :return: The enable of this DevicegroupSchemaOpenconfigGnmi.  # noqa: E501
        :rtype: bool
        """
        return self._enable

    @enable.setter
    def enable(self, enable):
        """Sets the enable of this DevicegroupSchemaOpenconfigGnmi.

        If true, enable gnmi  # noqa: E501

        :param enable: The enable of this DevicegroupSchemaOpenconfigGnmi.  # noqa: E501
        :type: bool
        """

        self._enable = enable

    @property
    def encoding(self):
        """Gets the encoding of this DevicegroupSchemaOpenconfigGnmi.  # noqa: E501

        Encoding to be used, default is protobuf  # noqa: E501

        :return: The encoding of this DevicegroupSchemaOpenconfigGnmi.  # noqa: E501
        :rtype: str
        """
        return self._encoding

    @encoding.setter
    def encoding(self, encoding):
        """Sets the encoding of this DevicegroupSchemaOpenconfigGnmi.

        Encoding to be used, default is protobuf  # noqa: E501

        :param encoding: The encoding of this DevicegroupSchemaOpenconfigGnmi.  # noqa: E501
        :type: str
        """
        allowed_values = ["protobuf", "json", "json_ietf"]  # noqa: E501
        if encoding not in allowed_values:
            raise ValueError(
                "Invalid value for `encoding` ({0}), must be one of {1}"  # noqa: E501
                .format(encoding, allowed_values)
            )

        self._encoding = encoding

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DevicegroupSchemaOpenconfigGnmi, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DevicegroupSchemaOpenconfigGnmi):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class RuleSchemaThen(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'next': 'list[object]',
        'status': 'RuleSchemaThenStatus',
        'user_defined_action': 'list[RuleSchemaThenUserdefinedaction]',
        'workflow': 'list[RuleSchemaThenWorkflow]'
    }

    attribute_map = {
        'next': 'next',
        'status': 'status',
        'user_defined_action': 'user-defined-action',
        'workflow': 'workflow'
    }

    def __init__(self, next=None, status=None, user_defined_action=None, workflow=None):  # noqa: E501
        """RuleSchemaThen - a model defined in Swagger"""  # noqa: E501

        self._next = None
        self._status = None
        self._user_defined_action = None
        self._workflow = None
        self.discriminator = None

        if next is not None:
            self.next = next
        if status is not None:
            self.status = status
        if user_defined_action is not None:
            self.user_defined_action = user_defined_action
        if workflow is not None:
            self.workflow = workflow

    @property
    def next(self):
        """Gets the next of this RuleSchemaThen.  # noqa: E501

        Continue evaluating next term in a trigger  # noqa: E501

        :return: The next of this RuleSchemaThen.  # noqa: E501
        :rtype: list[object]
        """
        return self._next

    @next.setter
    def next(self, next):
        """Sets the next of this RuleSchemaThen.

        Continue evaluating next term in a trigger  # noqa: E501

        :param next: The next of this RuleSchemaThen.  # noqa: E501
        :type: list[object]
        """

        self._next = next

    @property
    def status(self):
        """Gets the status of this RuleSchemaThen.  # noqa: E501


        :return: The status of this RuleSchemaThen.  # noqa: E501
        :rtype: RuleSchemaThenStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this RuleSchemaThen.


        :param status: The status of this RuleSchemaThen.  # noqa: E501
        :type: RuleSchemaThenStatus
        """

        self._status = status

    @property
    def user_defined_action(self):
        """Gets the user_defined_action of this RuleSchemaThen.  # noqa: E501


        :return: The user_defined_action of this RuleSchemaThen.  # noqa: E501
        :rtype: list[RuleSchemaThenUserdefinedaction]
        """
        return self._user_defined_action

    @user_defined_action.setter
    def user_defined_action(self, user_defined_action):
        """Sets the user_defined_action of this RuleSchemaThen.


        :param user_defined_action: The user_defined_action of this RuleSchemaThen.  # noqa: E501
        :type: list[RuleSchemaThenUserdefinedaction]
        """

        self._user_defined_action = user_defined_action

    @property
    def workflow(self):
        """Gets the workflow of this RuleSchemaThen.  # noqa: E501

        Trigger workflow execution  # noqa: E501

        :return: The workflow of this RuleSchemaThen.  # noqa: E501
        :rtype: list[RuleSchemaThenWorkflow]
        """
        return self._workflow

    @workflow.setter
    def workflow(self, workflow):
        """Sets the workflow of this RuleSchemaThen.

        Trigger workflow execution  # noqa: E501

        :param workflow: The workflow of this RuleSchemaThen.  # noqa: E501
        :type: list[RuleSchemaThenWorkflow]
        """

        self._workflow = workflow

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RuleSchemaThen, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RuleSchemaThen):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class NotificationSchemaKafkapublish(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'bootstrap_servers': 'list[str]',
        'sasl': 'NotificationSchemaKafkapublishSasl',
        'topic': 'str',
        'use_hash_partitioner': 'bool'
    }

    attribute_map = {
        'bootstrap_servers': 'bootstrap-servers',
        'sasl': 'sasl',
        'topic': 'topic',
        'use_hash_partitioner': 'use-hash-partitioner'
    }

    def __init__(self, bootstrap_servers=None, sasl=None, topic=None, use_hash_partitioner=None):  # noqa: E501
        """NotificationSchemaKafkapublish - a model defined in Swagger"""  # noqa: E501

        self._bootstrap_servers = None
        self._sasl = None
        self._topic = None
        self._use_hash_partitioner = None
        self.discriminator = None

        self.bootstrap_servers = bootstrap_servers
        if sasl is not None:
            self.sasl = sasl
        if topic is not None:
            self.topic = topic
        if use_hash_partitioner is not None:
            self.use_hash_partitioner = use_hash_partitioner

    @property
    def bootstrap_servers(self):
        """Gets the bootstrap_servers of this NotificationSchemaKafkapublish.  # noqa: E501


        :return: The bootstrap_servers of this NotificationSchemaKafkapublish.  # noqa: E501
        :rtype: list[str]
        """
        return self._bootstrap_servers

    @bootstrap_servers.setter
    def bootstrap_servers(self, bootstrap_servers):
        """Sets the bootstrap_servers of this NotificationSchemaKafkapublish.


        :param bootstrap_servers: The bootstrap_servers of this NotificationSchemaKafkapublish.  # noqa: E501
        :type: list[str]
        """
        if bootstrap_servers is None:
            raise ValueError("Invalid value for `bootstrap_servers`, must not be `None`")  # noqa: E501

        self._bootstrap_servers = bootstrap_servers

    @property
    def sasl(self):
        """Gets the sasl of this NotificationSchemaKafkapublish.  # noqa: E501


        :return: The sasl of this NotificationSchemaKafkapublish.  # noqa: E501
        :rtype: NotificationSchemaKafkapublishSasl
        """
        return self._sasl

    @sasl.setter
    def sasl(self, sasl):
        """Sets the sasl of this NotificationSchemaKafkapublish.


        :param sasl: The sasl of this NotificationSchemaKafkapublish.  # noqa: E501
        :type: NotificationSchemaKafkapublishSasl
        """

        self._sasl = sasl

    @property
    def topic(self):
        """Gets the topic of this NotificationSchemaKafkapublish.  # noqa: E501

        Kafka topic to which Healthbot should publish. Should be of pattern \\.*[a-zA-Z0-9_-]+[a-zA-Z0-9\\._-]* , Default value is derived from <device/network-group>.<device-id>.<topic>.<rule>.<trigger>  # noqa: E501

        :return: The topic of this NotificationSchemaKafkapublish.  # noqa: E501
        :rtype: str
        """
        return self._topic

    @topic.setter
    def topic(self, topic):
        """Sets the topic of this NotificationSchemaKafkapublish.

        Kafka topic to which Healthbot should publish. Should be of pattern \\.*[a-zA-Z0-9_-]+[a-zA-Z0-9\\._-]* , Default value is derived from <device/network-group>.<device-id>.<topic>.<rule>.<trigger>  # noqa: E501

        :param topic: The topic of this NotificationSchemaKafkapublish.  # noqa: E501
        :type: str
        """
        if topic is not None and len(topic) > 249:
            raise ValueError("Invalid value for `topic`, length must be less than or equal to `249`")  # noqa: E501
        if topic is not None and not re.search(r'^\\.*[a-zA-Z0-9_-]+[a-zA-Z0-9\\._-]*$', topic):  # noqa: E501
            raise ValueError(r"Invalid value for `topic`, must be a follow pattern or equal to `/^\\.*[a-zA-Z0-9_-]+[a-zA-Z0-9\\._-]*$/`")  # noqa: E501

        self._topic = topic

    @property
    def use_hash_partitioner(self):
        """Gets the use_hash_partitioner of this NotificationSchemaKafkapublish.  # noqa: E501

        If true, key will be generated which will be hashed to provide a consistent partition number for the given kafka topic  # noqa: E501

        :return: The use_hash_partitioner of this NotificationSchemaKafkapublish.  # noqa: E501
        :rtype: bool
        """
        return self._use_hash_partitioner

    @use_hash_partitioner.setter
    def use_hash_partitioner(self, use_hash_partitioner):
        """Sets the use_hash_partitioner of this NotificationSchemaKafkapublish.

        If true, key will be generated which will be hashed to provide a consistent partition number for the given kafka topic  # noqa: E501

        :param use_hash_partitioner: The use_hash_partitioner of this NotificationSchemaKafkapublish.  # noqa: E501
        :type: bool
        """

        self._use_hash_partitioner = use_hash_partitioner

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(NotificationSchemaKafkapublish, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NotificationSchemaKafkapublish):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class RuleSchemaFormulaMicroburst(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'if_name': 'str',
        'packets': 'str',
        'percentage': 'str',
        'queue_no': 'str'
    }

    attribute_map = {
        'if_name': 'if-name',
        'packets': 'packets',
        'percentage': 'percentage',
        'queue_no': 'queue-no'
    }

    def __init__(self, if_name=None, packets=None, percentage=None, queue_no=None):  # noqa: E501
        """RuleSchemaFormulaMicroburst - a model defined in Swagger"""  # noqa: E501

        self._if_name = None
        self._packets = None
        self._percentage = None
        self._queue_no = None
        self.discriminator = None

        self.if_name = if_name
        self.packets = packets
        self.percentage = percentage
        self.queue_no = queue_no

    @property
    def if_name(self):
        """Gets the if_name of this RuleSchemaFormulaMicroburst.  # noqa: E501

        Interface name. This should be field name where interface names are being stored  # noqa: E501

        :return: The if_name of this RuleSchemaFormulaMicroburst.  # noqa: E501
        :rtype: str
        """
        return self._if_name

    @if_name.setter
    def if_name(self, if_name):
        """Sets the if_name of this RuleSchemaFormulaMicroburst.

        Interface name. This should be field name where interface names are being stored  # noqa: E501

        :param if_name: The if_name of this RuleSchemaFormulaMicroburst.  # noqa: E501
        :type: str
        """
        if if_name is None:
            raise ValueError("Invalid value for `if_name`, must not be `None`")  # noqa: E501

        self._if_name = if_name

    @property
    def packets(self):
        """Gets the packets of this RuleSchemaFormulaMicroburst.  # noqa: E501

        Queue egress packets. This should be field name where queue egress packets are being stored  # noqa: E501

        :return: The packets of this RuleSchemaFormulaMicroburst.  # noqa: E501
        :rtype: str
        """
        return self._packets

    @packets.setter
    def packets(self, packets):
        """Sets the packets of this RuleSchemaFormulaMicroburst.

        Queue egress packets. This should be field name where queue egress packets are being stored  # noqa: E501

        :param packets: The packets of this RuleSchemaFormulaMicroburst.  # noqa: E501
        :type: str
        """
        if packets is None:
            raise ValueError("Invalid value for `packets`, must not be `None`")  # noqa: E501

        self._packets = packets

    @property
    def percentage(self):
        """Gets the percentage of this RuleSchemaFormulaMicroburst.  # noqa: E501

        Queue buffer occupancy percentage. This should be field name where queue buffer occupancy percentage are being stored  # noqa: E501

        :return: The percentage of this RuleSchemaFormulaMicroburst.  # noqa: E501
        :rtype: str
        """
        return self._percentage

    @percentage.setter
    def percentage(self, percentage):
        """Sets the percentage of this RuleSchemaFormulaMicroburst.

        Queue buffer occupancy percentage. This should be field name where queue buffer occupancy percentage are being stored  # noqa: E501

        :param percentage: The percentage of this RuleSchemaFormulaMicroburst.  # noqa: E501
        :type: str
        """
        if percentage is None:
            raise ValueError("Invalid value for `percentage`, must not be `None`")  # noqa: E501

        self._percentage = percentage

    @property
    def queue_no(self):
        """Gets the queue_no of this RuleSchemaFormulaMicroburst.  # noqa: E501

        Queue numbers. This should be field name where queue numbers are being stored  # noqa: E501

        :return: The queue_no of this RuleSchemaFormulaMicroburst.  # noqa: E501
        :rtype: str
        """
        return self._queue_no

    @queue_no.setter
    def queue_no(self, queue_no):
        """Sets the queue_no of this RuleSchemaFormulaMicroburst.

        Queue numbers. This should be field name where queue numbers are being stored  # noqa: E501

        :param queue_no: The queue_no of this RuleSchemaFormulaMicroburst.  # noqa: E501
        :type: str
        """
        if queue_no is None:
            raise ValueError("Invalid value for `queue_no`, must not be `None`")  # noqa: E501

        self._queue_no = queue_no

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RuleSchemaFormulaMicroburst, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RuleSchemaFormulaMicroburst):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class RuleSchemaWhenRange(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'all': 'list[object]',
        'any': 'list[object]',
        'field_name': 'str',
        'max': 'float',
        'min': 'float',
        'time_range': 'str'
    }

    attribute_map = {
        'all': 'all',
        'any': 'any',
        'field_name': 'field-name',
        'max': 'max',
        'min': 'min',
        'time_range': 'time-range'
    }

    def __init__(self, all=None, any=None, field_name=None, max=None, min=None, time_range=None):  # noqa: E501
        """RuleSchemaWhenRange - a model defined in Swagger"""  # noqa: E501

        self._all = None
        self._any = None
        self._field_name = None
        self._max = None
        self._min = None
        self._time_range = None
        self.discriminator = None

        if all is not None:
            self.all = all
        if any is not None:
            self.any = any
        self.field_name = field_name
        self.max = max
        self.min = min
        if time_range is not None:
            self.time_range = time_range

    @property
    def all(self):
        """Gets the all of this RuleSchemaWhenRange.  # noqa: E501

        With this flag, result is set to True only if all the data matches the given condition  # noqa: E501

        :return: The all of this RuleSchemaWhenRange.  # noqa: E501
        :rtype: list[object]
        """
        return self._all

    @all.setter
    def all(self, all):
        """Sets the all of this RuleSchemaWhenRange.

        With this flag, result is set to True only if all the data matches the given condition  # noqa: E501

        :param all: The all of this RuleSchemaWhenRange.  # noqa: E501
        :type: list[object]
        """

        self._all = all

    @property
    def any(self):
        """Gets the any of this RuleSchemaWhenRange.  # noqa: E501

        With this flag, result is set to True if any one of the data matches the condition  # noqa: E501

        :return: The any of this RuleSchemaWhenRange.  # noqa: E501
        :rtype: list[object]
        """
        return self._any

    @any.setter
    def any(self, any):
        """Sets the any of this RuleSchemaWhenRange.

        With this flag, result is set to True if any one of the data matches the condition  # noqa: E501

        :param any: The any of this RuleSchemaWhenRange.  # noqa: E501
        :type: list[object]
        """

        self._any = any

    @property
    def field_name(self):
        """Gets the field_name of this RuleSchemaWhenRange.  # noqa: E501

        Field name on which range should be applied  # noqa: E501

        :return: The field_name of this RuleSchemaWhenRange.  # noqa: E501
        :rtype: str
        """
        return self._field_name

    @field_name.setter
    def field_name(self, field_name):
        """Sets the field_name of this RuleSchemaWhenRange.

        Field name on which range should be applied  # noqa: E501

        :param field_name: The field_name of this RuleSchemaWhenRange.  # noqa: E501
        :type: str
        """
        if field_name is None:
            raise ValueError("Invalid value for `field_name`, must not be `None`")  # noqa: E501

        self._field_name = field_name

    @property
    def max(self):
        """Gets the max of this RuleSchemaWhenRange.  # noqa: E501

        Maximum value in the range  # noqa: E501

        :return: The max of this RuleSchemaWhenRange.  # noqa: E501
        :rtype: float
        """
        return self._max

    @max.setter
    def max(self, max):
        """Sets the max of this RuleSchemaWhenRange.

        Maximum value in the range  # noqa: E501

        :param max: The max of this RuleSchemaWhenRange.  # noqa: E501
        :type: float
        """
        if max is None:
            raise ValueError("Invalid value for `max`, must not be `None`")  # noqa: E501

        self._max = max

    @property
    def min(self):
        """Gets the min of this RuleSchemaWhenRange.  # noqa: E501

        Minumum value in the range  # noqa: E501

        :return: The min of this RuleSchemaWhenRange.  # noqa: E501
        :rtype: float
        """
        return self._min

    @min.setter
    def min(self, min):
        """Sets the min of this RuleSchemaWhenRange.

        Minumum value in the range  # noqa: E501

        :param min: The min of this RuleSchemaWhenRange.  # noqa: E501
        :type: float
        """
        if min is None:
            raise ValueError("Invalid value for `min`, must not be `None`")  # noqa: E501

        self._min = min

    @property
    def time_range(self):
        """Gets the time_range of this RuleSchemaWhenRange.  # noqa: E501

        How much back in time should we look for data. Specify positive integer followed by s/m/h/d/w/y/o representing seconds/minutes/hours/days/weeks/years/offset. Eg: 2s  # noqa: E501

        :return: The time_range of this RuleSchemaWhenRange.  # noqa: E501
        :rtype: str
        """
        return self._time_range

    @time_range.setter
    def time_range(self, time_range):
        """Sets the time_range of this RuleSchemaWhenRange.

        How much back in time should we look for data. Specify positive integer followed by s/m/h/d/w/y/o representing seconds/minutes/hours/days/weeks/years/offset. Eg: 2s  # noqa: E501

        :param time_range: The time_range of this RuleSchemaWhenRange.  # noqa: E501
        :type: str
        """
        if time_range is not None and not re.search(r'^[1-9][0-9]*(\\.[0-9]+)?(o|s|m|h|d|w|y|offset)$', time_range):  # noqa: E501
            raise ValueError(r"Invalid value for `time_range`, must be a follow pattern or equal to `/^[1-9][0-9]*(\\.[0-9]+)?(o|s|m|h|d|w|y|offset)$/`")  # noqa: E501

        self._time_range = time_range

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RuleSchemaWhenRange, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RuleSchemaWhenRange):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Paragon Insights APIs

    API interface for PI application  # noqa: E501

    OpenAPI spec version: 4.0.0
    Contact: healthbot-feedback@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class RuleSchemaFormulaOutlierdetectionAlgorithmKfold3sigma(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'learning_period': 'str',
        'sensitivity': 'RuleSchemaFormulaOutlierdetectionAlgorithmDbscanSensitivity',
        'sigma_coefficient': 'float'
    }

    attribute_map = {
        'learning_period': 'learning-period',
        'sensitivity': 'sensitivity',
        'sigma_coefficient': 'sigma-coefficient'
    }

    def __init__(self, learning_period=None, sensitivity=None, sigma_coefficient=None):  # noqa: E501
        """RuleSchemaFormulaOutlierdetectionAlgorithmKfold3sigma - a model defined in Swagger"""  # noqa: E501

        self._learning_period = None
        self._sensitivity = None
        self._sigma_coefficient = None
        self.discriminator = None

        self.learning_period = learning_period
        if sensitivity is not None:
            self.sensitivity = sensitivity
        if sigma_coefficient is not None:
            self.sigma_coefficient = sigma_coefficient

    @property
    def learning_period(self):
        """Gets the learning_period of this RuleSchemaFormulaOutlierdetectionAlgorithmKfold3sigma.  # noqa: E501

        Time period on which to detect outliers  # noqa: E501

        :return: The learning_period of this RuleSchemaFormulaOutlierdetectionAlgorithmKfold3sigma.  # noqa: E501
        :rtype: str
        """
        return self._learning_period

    @learning_period.setter
    def learning_period(self, learning_period):
        """Sets the learning_period of this RuleSchemaFormulaOutlierdetectionAlgorithmKfold3sigma.

        Time period on which to detect outliers  # noqa: E501

        :param learning_period: The learning_period of this RuleSchemaFormulaOutlierdetectionAlgorithmKfold3sigma.  # noqa: E501
        :type: str
        """
        if learning_period is None:
            raise ValueError("Invalid value for `learning_period`, must not be `None`")  # noqa: E501
        if learning_period is not None and not re.search(r'^[1-9][0-9]*(\\.[0-9]+)?(o|s|m|h|d|w|y|offset)$', learning_period):  # noqa: E501
            raise ValueError(r"Invalid value for `learning_period`, must be a follow pattern or equal to `/^[1-9][0-9]*(\\.[0-9]+)?(o|s|m|h|d|w|y|offset)$/`")  # noqa: E501

        self._learning_period = learning_period

    @property
    def sensitivity(self):
        """Gets the sensitivity of this RuleSchemaFormulaOutlierdetectionAlgorithmKfold3sigma.  # noqa: E501


        :return: The sensitivity of this RuleSchemaFormulaOutlierdetectionAlgorithmKfold3sigma.  # noqa: E501
        :rtype: RuleSchemaFormulaOutlierdetectionAlgorithmDbscanSensitivity
        """
        return self._sensitivity

    @sensitivity.setter
    def sensitivity(self, sensitivity):
        """Sets the sensitivity of this RuleSchemaFormulaOutlierdetectionAlgorithmKfold3sigma.


        :param sensitivity: The sensitivity of this RuleSchemaFormulaOutlierdetectionAlgorithmKfold3sigma.  # noqa: E501
        :type: RuleSchemaFormulaOutlierdetectionAlgorithmDbscanSensitivity
        """

        self._sensitivity = sensitivity

    @property
    def sigma_coefficient(self):
        """Gets the sigma_coefficient of this RuleSchemaFormulaOutlierdetectionAlgorithmKfold3sigma.  # noqa: E501

        Number of standard deviations past which outliers are marked  # noqa: E501

        :return: The sigma_coefficient of this RuleSchemaFormulaOutlierdetectionAlgorithmKfold3sigma.  # noqa: E501
        :rtype: float
        """
        return self._sigma_coefficient

    @sigma_coefficient.setter
    def sigma_coefficient(self, sigma_coefficient):
        """Sets the sigma_coefficient of this RuleSchemaFormulaOutlierdetectionAlgorithmKfold3sigma.

        Number of standard deviations past which outliers are marked  # noqa: E501

        :param sigma_coefficient: The sigma_coefficient of this RuleSchemaFormulaOutlierdetectionAlgorithmKfold3sigma.  # noqa: E501
        :type: float
        """

        self._sigma_coefficient = sigma_coefficient

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RuleSchemaFormulaOutlierdetectionAlgorithmKfold3sigma, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RuleSchemaFormulaOutlierdetectionAlgorithmKfold3sigma):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Healthbot APIs

    API interface for Healthbot application  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: healthbot-hackers@juniper.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class IngestsettingsSchemaIngestsettings(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'flow': 'IngestsettingsSchemaIngestsettingsFlow',
        'syslog': 'IngestsettingsSchemaIngestsettingsSyslog',
        'byoi': 'IngestsettingsSchemaIngestsettingsByoi',
        'frequency_profile': 'list[IngestsettingsSchemaIngestsettingsFrequencyprofile]'
    }

    attribute_map = {
        'flow': 'flow',
        'syslog': 'syslog',
        'byoi': 'byoi',
        'frequency_profile': 'frequency-profile'
    }

    def __init__(self, flow=None, syslog=None, byoi=None, frequency_profile=None):  # noqa: E501
        """IngestsettingsSchemaIngestsettings - a model defined in Swagger"""  # noqa: E501

        self._flow = None
        self._syslog = None
        self._byoi = None
        self._frequency_profile = None
        self.discriminator = None

        if flow is not None:
            self.flow = flow
        if syslog is not None:
            self.syslog = syslog
        if byoi is not None:
            self.byoi = byoi
        if frequency_profile is not None:
            self.frequency_profile = frequency_profile

    @property
    def flow(self):
        """Gets the flow of this IngestsettingsSchemaIngestsettings.  # noqa: E501


        :return: The flow of this IngestsettingsSchemaIngestsettings.  # noqa: E501
        :rtype: IngestsettingsSchemaIngestsettingsFlow
        """
        return self._flow

    @flow.setter
    def flow(self, flow):
        """Sets the flow of this IngestsettingsSchemaIngestsettings.


        :param flow: The flow of this IngestsettingsSchemaIngestsettings.  # noqa: E501
        :type: IngestsettingsSchemaIngestsettingsFlow
        """

        self._flow = flow

    @property
    def syslog(self):
        """Gets the syslog of this IngestsettingsSchemaIngestsettings.  # noqa: E501


        :return: The syslog of this IngestsettingsSchemaIngestsettings.  # noqa: E501
        :rtype: IngestsettingsSchemaIngestsettingsSyslog
        """
        return self._syslog

    @syslog.setter
    def syslog(self, syslog):
        """Sets the syslog of this IngestsettingsSchemaIngestsettings.


        :param syslog: The syslog of this IngestsettingsSchemaIngestsettings.  # noqa: E501
        :type: IngestsettingsSchemaIngestsettingsSyslog
        """

        self._syslog = syslog

    @property
    def byoi(self):
        """Gets the byoi of this IngestsettingsSchemaIngestsettings.  # noqa: E501


        :return: The byoi of this IngestsettingsSchemaIngestsettings.  # noqa: E501
        :rtype: IngestsettingsSchemaIngestsettingsByoi
        """
        return self._byoi

    @byoi.setter
    def byoi(self, byoi):
        """Sets the byoi of this IngestsettingsSchemaIngestsettings.


        :param byoi: The byoi of this IngestsettingsSchemaIngestsettings.  # noqa: E501
        :type: IngestsettingsSchemaIngestsettingsByoi
        """

        self._byoi = byoi

    @property
    def frequency_profile(self):
        """Gets the frequency_profile of this IngestsettingsSchemaIngestsettings.  # noqa: E501


        :return: The frequency_profile of this IngestsettingsSchemaIngestsettings.  # noqa: E501
        :rtype: list[IngestsettingsSchemaIngestsettingsFrequencyprofile]
        """
        return self._frequency_profile

    @frequency_profile.setter
    def frequency_profile(self, frequency_profile):
        """Sets the frequency_profile of this IngestsettingsSchemaIngestsettings.


        :param frequency_profile: The frequency_profile of this IngestsettingsSchemaIngestsettings.  # noqa: E501
        :type: list[IngestsettingsSchemaIngestsettingsFrequencyprofile]
        """

        self._frequency_profile = frequency_profile

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(IngestsettingsSchemaIngestsettings, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IngestsettingsSchemaIngestsettings):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
